(* ::Package:: *)

(*:Package Version: 4.04 *)

(*:Version History: 1.01 (2004.07.11 - 2010.07.18)
                    2.01 (2010.07.19 - 2010.08.16)
                    2.02 (2010.08.17 - 2010.09.19)
                    3.01 (2010.09.20 - 2011.05.26)
                    4.01 (2011.05.27 - 2011.06.19)
                    4.02 (2011.06.20 - 2012.03.22)
                    4.03 (2012.03.23 - 2016.01.18)
                    4.04 (2016.01.19 -     .  .  ) ClassicalP2, PainleveP6*)

(*:Copyright: Copyright 2004.07-2016.01, Souichiro Ikebe *)

(*:Author: Souichiro Ikebe *)

(*:Name: SpecialFunctions`Painleve` *)

(*:Title: Painleve, ClassicalPainleve, YablonskiiVorobev *)

(*:Keywords: PainleveP1, PainleveP2, ModifiedPainleveP2,
   PainleveP3, PainleveP3Alternative, PainleveP3Exp, PainleveP4, 
   PainleveP5, PainleveP5Alternative, PainleveP5Exp, PainleveP6, 
   DegeneratePainleveD7, DegeneratePainleveD7Alternative, 
   DegeneratePainleveD8, DegeneratePainleveD8Alternative,    
   QuasiPainleveE1, QuasiPainleveE2, QuasiPainleveF1, 
   YablonskiiVorobevQ, ClassicalPainleveP2, ClassicalPainleveP2Prime, 
   ClassicalOrder4PainleveP2, ClassicalOrder4PainleveP2Prime, 
   ClassicalOrder4PainleveP2Prime2, ClassicalOrder4PainleveP2Prime3, 
   ClassicalOrder6PainleveP2, ClassicalOrder6PainleveP2Prime, 
   ClassicalOrder6PainleveP2Prime2, ClassicalOrder6PainleveP2Prime3, 
   ClassicalOrder6PainleveP2Prime4, ClassicalOrder6PainleveP2Prime5, 
   ClassicalOrder4KaupKupershmidt, ClassicalOrder4KaupKupershmidtPrime, 
   ClassicalOrder4KaupKupershmidtPrime2, 
   ClassicalOrder4KaupKupershmidtPrime3 *)

(*:Summary:
   This package implements the Painleve functions.
*)

(**********************************************************************)





BeginPackage["SpecialFunctions`Painleve`"]





PainleveP1::usage =
"PainleveP1[z,{v,w}] gives the solutions of the Painleve-1
 equation : y''[z]=6 y[z]^2+z; y[0]=v; y'[0]=w."

PainleveP2::usage =
"PainleveP2[z,a,{v,w}] gives the solutions of the Painleve-2
 equation : y''[z]=2 y[z]^3+z y[z]+a; y[0]=v; y'[0]=w."

ModifiedPainleveP2::usage =
"ModifiedPainleveP2[z,a,{v,w}] gives the other solutions of the
 modified Painleve-2 equation : 
 y''[z]=-2 y[z]^3+z y[z]+a; y[0]=v; y'[0]=w."

PainleveP3::usage =
"PainleveP3[z,{a,b,c,d},{v,w}] gives the solutions of the
 Painleve-3 equation : 
 y''[z]=y'[z]^2/y[z]-y'[z]/z+a y[z]^3+b/z y[z]^2+c/z+d/y[z]; 
 y[1]=v; y'[1]=w."

PainleveP3Alternative::usage =
"PainleveP3Alternative[z,{a,b,c,d},{v,w}] gives the solutions
 of the alternative Painleve-3 equation : 
 y''[z]=y'[z]^2/y[z]-y'[z]/z+a y[z]^3/(4 z^2)+b/(4 z^2) y[z]^2+
 c/(4 z)+d/(4 y[z]); y[1]=v; y'[1]=w.
 PainleveP3[z,{a,b,c,d},{v,w}]=
 PainleveP3Alternative[z^2,{a,b,c,d},{v,w}]/z."

PainleveP3Exp::usage =
"PainleveP3Exp[z,{a,b,c,d},{v,w}] gives the analytic continuation
 of the exponential function in the alternative Painleve-3 functions : 
 Exp[z/2]*PainleveP3[Exp[z/2],{a,b,c,d},{v,w}].
 This functions can be analytically continued to single-valued 
 meromorphic functions in the complex plane."

PainleveP4::usage =
"PainleveP4[z,{a,b},{v,w}] gives the solutions of the Painleve-4
 equation : 
 y''[z]=y'[z]^2/(2 y[z])+a/y[z]-2 (b-z^2) y[z]+4 z y[z]^2+3/2 y[z]^3; 
 y[0]=v; y'[0]=w."

PainleveP5::usage =
"PainleveP5[z,{a,b,c,d},{v,w}] gives the solutions of the Painleve-5
 equation : y''[z]=(1/(2 y[z])+1/(y[z]-1)) y'[z]^2-y'[z]/z+
 (y[z]-1)^2/z^2 (a y[z]+b/y[z])+c/z y[z]+d y[z] (y[z]+1)/(y[z]-1); 
 y[1]=v; y'[1]=w."

PainleveP5Alternative::usage =
"PainleveP5Alternative[z,{a,b,c,d},{v,w}] gives the solutions of the
 alternative Painleve-5 equation : 
 y''[z]=(1/y[z]+1/(y[z]-1))/2 y'[z]^2-y'[z]/z-1/z^2*
 (a y[z]/(y[z]-1)+b (y[z]-1)/y[z])-c/z y[z] (y[z]-1)-
 d y[z] (y[z]-1) (2 y[z]-1); 
 y[1]=v; y'[1]=w."

PainleveP5Exp::usage =
"PainleveP5Exp[z,{a,b,c,d},{v,w}] gives the analytic continuation
 of the exponential function in the Painleve-5 functions : 
 PainleveP5[Exp[z],{a,b,c,d},{v,w}].
 This functions can be analytically continued to single-valued 
 meromorphic functions in the complex plane."

PainleveP6::usage =
"PainleveP6[z,{a,b,c,d},{v,w}] gives the solutions of the Painleve-6
 equation : y''[z]=1/2 (1/y[z]+1/(y[z]-1)+1/(y[z]-z)) y'[z]^2-
 (1/z+1/(z-1)+1/(y[z]-z)) y'[z]+y[z] (y[z]-1) (y[z]-z)/(z^2 (z-1)^2)*
 (a+b z/y[z]^2+c (z-1)/(y[z]-1)^2+d z (z-1)/(y[z]-z)^2); 
 y[1/2]=v; y'[1/2]=w."

DegeneratePainleveD7::usage =
"DegeneratePainleveD7[z,a,{v,w}] gives the solutions of the
 Painleve-D7 equation from degenerate Painleve-3 equation : 
 y''[z]=y'[z]^2/y[z]-y'[z]/z-4/z y[z]^2-4/y[z]+4 (1-a)/z; 
 y[1]=v; y'[1]=w."

DegeneratePainleveD7Alternative::usage =
"DegeneratePainleveD7Alternative[z,a,{v,w}] gives the solutions of the
 alternative Painleve-D7 equation from degenerate Painleve-3 equation : 
 y''[z]=y'[z]^2/y[z]-y'[z]/z-(y[z]/z)^2-1/y[z]+(1-a)/z; 
 y[1]=v; y'[1]=w."

DegeneratePainleveD8::usage =
"DegeneratePainleveD8[z,{v,w}] gives the solutions of the
 Painleve-D8 equation from degenerate Painleve-D7 equation : 
 y''[z]=y'[z]^2/y[z]-y'[z]/z-4/z y[z]^2+4/z; 
 y[1]=v; y'[1]=w."

DegeneratePainleveD8Alternative::usage =
"DegeneratePainleveD8Alternative[z,{v,w}] gives the solutions of the
 alternative Painleve-D8 equation from degenerate Painleve-D7 equation : 
 y''[z]=y'[z]^2/y[z]-y'[z]/z-(y[z]/z)^2+1/z; 
 y[1]=v; y'[1]=w."

QuasiPainleveE1::usage =
"QuasiPainleveE1[z,{v,w}] gives the solutions of the quasi
 Painleve-E1 equation : y''[z]=10/9 y[z]^4+z; y[0]=v; y'[0]=w."

QuasiPainleveE2::usage =
"QuasiPainleveE2[z,a,{v,w}] gives the solutions of the quasi
 Painleve-E2 equation : y''[z]=3/4 y[z]^5+z y[z]^2+a; y[0]=v; y'[0]=w."

QuasiPainleveF1::usage =
"QuasiPainleveF1[z,{v,w}] gives the solutions of the quasi
 Painleve-F1 equation : y''[z]=2 y[z]^3+z; y[0]=v; y'[0]=w."

YablonskiiVorobevQ::usage =
"YablonskiiVorobevQ[n,z] gives the Yablonskii-Vorob'ev polynomials in 
 rational function solutions of the Painleve-2 equation, 
 with n is integers.
 YablonskiiVorobevQ[m,n,z] gives the 2m-th order Yablonskii-Vorob'ev 
 polynomials in rational function solutions of the 2m-th order 
 Painleve-2 equation hierarchy, with m,n is integers.
 YablonskiiVorobevQ[1,n,z]=YablonskiiVorobevQ[n,z]."

ClassicalPainleveP2::usage =
"ClassicalPainleveP2[n,z] gives the rational function solutions of the 
 Painleve-2 equation, with n is integers.
 ClassicalPainleveP2[n/2,{z,c}] gives the Airy function solutions of the 
 Painleve-2 equation, with n is odd numbers, c is real, complex numbers, 
 and infinity."

ClassicalPainleveP2Prime::usage =
"ClassicalPainleveP2Prime[n,z] or ClassicalPainleveP2Prime[n/2,{z,c}] gives 
 the rational or Airy function solutions of the Painleve-2 equation 
 derivative of z."

ClassicalOrder4PainleveP2::usage =
"ClassicalOrder4PainleveP2[n,z] gives the rational function solutions of the 
 Order-4 Painleve-2 equation, with n is integers."

ClassicalOrder4PainleveP2Prime::usage =
"ClassicalOrder4PainleveP2Prime[n,z] gives the rational function solutions 
 of the Order-4 Painleve-2 equation derivative of z."

ClassicalOrder4PainleveP2Prime2::usage =
"ClassicalOrder4PainleveP2Prime2[n,z] gives the rational function solutions 
 of the Order-4 Painleve-2 equation 2nd-derivative of z."

ClassicalOrder4PainleveP2Prime3::usage =
"ClassicalOrder4PainleveP2Prime3[n,z] gives the rational function solutions 
 of the Order-4 Painleve-2 equation 3rd-derivative of z."

ClassicalOrder6PainleveP2::usage =
"ClassicalOrder6PainleveP2[n,z] gives the rational function solutions of the 
 Order-6 Painleve-2 equation, with n is integers."

ClassicalOrder6PainleveP2Prime::usage =
"ClassicalOrder6PainleveP2Prime[n,z] gives the rational function solutions 
 of the Order-6 Painleve-2 equation derivative of z."

ClassicalOrder6PainleveP2Prime2::usage =
"ClassicalOrder6PainleveP2Prime2[n,z] gives the rational function solutions 
 of the Order-6 Painleve-2 equation 2nd-derivative of z."

ClassicalOrder6PainleveP2Prime3::usage =
"ClassicalOrder6PainleveP2Prime3[n,z] gives the rational function solutions 
 of the Order-6 Painleve-2 equation 3rd-derivative of z."

ClassicalOrder6PainleveP2Prime4::usage =
"ClassicalOrder6PainleveP2Prime4[n,z] gives the rational function solutions 
 of the Order-6 Painleve-2 equation 4th-derivative of z."

ClassicalOrder6PainleveP2Prime5::usage =
"ClassicalOrder6PainleveP2Prime5[n,z] gives the rational function solutions 
 of the Order-6 Painleve-2 equation 5th-derivative of z."

ClassicalOrder4KaupKupershmidt::usage =
"ClassicalOrder4KaupKupershmidt[a,b,z] gives the rational function 
 solutions of the Order-4 reduced Kaup-Kupershmidt equation, 
 with b is integers in the case of Mod[b,3]===0 or Mod[b,3]===2."

ClassicalOrder4KaupKupershmidtPrime::usage =
"ClassicalOrder4KaupKupershmidtPrime[a,b,z] gives the rational function 
 solutions of the Order-4 reduced Kaup-Kupershmidt equation derivative of z, 
 with b is integers in the case of Mod[b,3]===0 or Mod[b,3]===2."

ClassicalOrder4KaupKupershmidtPrime2::usage =
"ClassicalOrder4KaupKupershmidtPrime2[a,b,z] gives the rational function 
 solutions of the Order-4 reduced Kaup-Kupershmidt equation 2nd-derivative of z, 
 with b is integers in the case of Mod[b,3]===0 or Mod[b,3]===2."

ClassicalOrder4KaupKupershmidtPrime3::usage =
"ClassicalOrder4KaupKupershmidtPrime3[a,b,z] gives the rational function 
 solutions of the Order-4 reduced Kaup-Kupershmidt equation 3rd-derivative of z, 
 with b is integers in the case of Mod[b,3]===0 or Mod[b,3]===2."





Begin["SpecialFunctions`Painleve`Private`"]





(**********************************************************************)
(*                        myDrop[list,{n,max}]                        *)
(**********************************************************************)

myDrop[exprList_,{n_,max_}]:=
  Module[{exLen=Length[exprList[[1]]]},
    If[n<Floor[max/100],exprList,
    Map[If[exLen<=Floor[max-n+2],#,
    Drop[#,-Floor[exLen-(max-n+2)]]]&,exprList]]];



(**********************************************************************)
(*                        PainleveP1[z,{v,w}]                         *)
(**********************************************************************)

PainleveP1[z_,{v_,w_}]:=
  v+w*z+3*v^2/continuFracP1[z,{v,w}]*z^2/;
  (Precision[z]<Infinity && N[v]=!=0.)

continuFracP1[z_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP1[{v,w}]];

alphaListP1[{v_,w_}]:=
  alphaListP1[{v,w}]=
    Module[{n,nMax,spV,spW,listA,listB,listC,listD,listE,listF,
     listG,listH,e0,f0,alpha,alphaList},
      n=1;
      nMax=3800;
      spV=SetPrecision[v,7000];
      spW=SetPrecision[w,7000];
      listA={0,0,1,0,0};
      listB={0,0,0,0,0};
      listC={0,4,0,0,0};
      listD={0,0,0,0,0};
      listE={-6*spV^2,-1-12*spV*spW,-6*spW^2,0,0};
      listF={2,0,-12*spV,-12*spW,0};
      listG={0,0,0,0,-6};
      listH={0,0,0,0,0};
      alpha=3*spV^2;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB,{0,0}],
         Join[{0},-listA,{0}],
         Join[Drop[-2*listA-2*alpha*listB,1],{0,0,0}]+
           Join[-listC-alpha*listD,{0,0}],
         Join[2*listA,{0,0}]+Join[{0},-listC,{0}],
         e0=Join[Drop[listE/alpha+listF+alpha*listG+alpha^2*listH,1],{0,0,0}],
         f0=Join[Drop[-listC-alpha*listD,1],{0,0,0}]+
           Join[3*listE/alpha+2*listF+alpha*listG,{0,0}],
         Join[Drop[2*listA,1],{0,0,0}]+Join[-listC,{0,0}]+
           Join[{0},3*listE/alpha+listF,{0}],
         Join[{0,0},listE/alpha]},{n,nMax}],
         -1*e0[[1]]/f0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,e0,f0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                       PainleveP2[z,a,{v,w}]                        *)
(**********************************************************************)

PainleveP2[z_,a_,{v_,w_}]:=
  v+w*z+(a/2+v^3)/continuFracP2[z,a,{v,w}]*z^2/;
  (Precision[z]<Infinity && N[a/2+v^3]=!=0.)

continuFracP2[z_,a_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP2[a,{v,w}]];

alphaListP2[a_,{v_,w_}]:=
  alphaListP2[a,{v,w}]=
    Module[{n,nMax,spA,spV,spW,listA,listB,listC,listD,listE,listF,
     listG,listH,e0,f0,alpha,alphaList},
      n=1;
      nMax=3500;
      spA=SetPrecision[a,7000];
      spV=SetPrecision[v,7000];
      spW=SetPrecision[w,7000];
      listA={0,0,1,0,0,0,0};
      listB={0,0,0,0,0,0,0};
      listC={0,4,0,0,0,0,0};
      listD={0,0,0,0,0,0,0};
      listE={-spA-2*spV^3,-spV*(1+6*spV*spW),-spW*(1+6*spV*spW),
        -2*spW^3,0,0,0};
      listF={2,0,-6*spV^2,-(1+12*spV*spW),-6*spW^2,0,0};
      listG={0,0,0,0,-6*spV,-6*spW,0};
      listH={0,0,0,0,0,0,-2};
      alpha=spA/2+spV^3;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB,{0,0}],
         Join[{0},-listA,{0}],
         Join[Drop[-2*listA-2*alpha*listB,1],{0,0,0}]+
           Join[-listC-alpha*listD,{0,0}],
         Join[2*listA,{0,0}]+Join[{0},-listC,{0}],
         e0=Join[Drop[listE/alpha+listF+alpha*listG+alpha^2*listH,1],{0,0,0}],
         f0=Join[Drop[-listC-alpha*listD,1],{0,0,0}]+
           Join[3*listE/alpha+2*listF+alpha*listG,{0,0}],
         Join[Drop[2*listA,1],{0,0,0}]+Join[-listC,{0,0}]+
           Join[{0},3*listE/alpha+listF,{0}],
         Join[{0,0},listE/alpha]},{n,nMax}],
         -1*e0[[1]]/f0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,e0,f0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                   ModifiedPainleveP2[z,a,{v,w}]                    *)
(**********************************************************************)

ModifiedPainleveP2[z_,a_,{v_,w_}]:=
  v+w*z+(a/2-v^3)/continuFracP2M[z,a,{v,w}]*z^2/;
  (Precision[z]<Infinity && N[a/2-v^3]=!=0.)

continuFracP2M[z_,a_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP2M[a,{v,w}]];

alphaListP2M[a_,{v_,w_}]:=
  alphaListP2M[a,{v,w}]=
    Module[{n,nMax,spA,spV,spW,listA,listB,listC,listD,listE,listF,
     listG,listH,e0,f0,alpha,alphaList},
      n=1;
      nMax=3500;
      spA=SetPrecision[a,7000];
      spV=SetPrecision[v,7000];
      spW=SetPrecision[w,7000];
      listA={0,0,1,0,0,0,0};
      listB={0,0,0,0,0,0,0};
      listC={0,4,0,0,0,0,0};
      listD={0,0,0,0,0,0,0};
      listE={-spA+2*spV^3,spV*(6*spV*spW-1),spW*(6*spV*spW-1),
        2*spW^3,0,0,0};
      listF={2,0,6*spV^2,12*spV*spW-1,6*spW^2,0,0};
      listG={0,0,0,0,6*spV,6*spW,0};
      listH={0,0,0,0,0,0,2};
      alpha=spA/2-spV^3;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB,{0,0}],
         Join[{0},-listA,{0}],
         Join[Drop[-2*listA-2*alpha*listB,1],{0,0,0}]+
           Join[-listC-alpha*listD,{0,0}],
         Join[2*listA,{0,0}]+Join[{0},-listC,{0}],
         e0=Join[Drop[listE/alpha+listF+alpha*listG+alpha^2*listH,1],{0,0,0}],
         f0=Join[Drop[-listC-alpha*listD,1],{0,0,0}]+
           Join[3*listE/alpha+2*listF+alpha*listG,{0,0}],
         Join[Drop[2*listA,1],{0,0,0}]+Join[-listC,{0,0}]+
           Join[{0},3*listE/alpha+listF,{0}],
         Join[{0,0},listE/alpha]},{n,nMax}],
         -1*e0[[1]]/f0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,e0,f0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                   PainleveP3[z,{a,b,c,d},{v,w}]                    *)
(**********************************************************************)

PainleveP3[z_,{a_,b_,c_,d_},{v_,w_}]:=
  Sqrt[z]*painleveP3Quad[Sqrt[z],{a,b,c,d},{v,2 w-v}];

PainleveP3Alternative[z_,{a_,b_,c_,d_},{v_,w_}]:=
  Sqrt[z]*PainleveP3[Sqrt[z],{a,b,c,d},{v,2 w-v}];

painleveP3Quad[z_,{a_,b_,c_,d_},{v_,w_}]:=
  v+w*(z-1)+((4 d+4 c v+4 b v^3+4 a v^4-v w+w^2)/(2*v))/
  continuFracP3[(z-1),{a,b,c,d},{v,w}]*(z-1)^2/;
  (Precision[z]<Infinity && N[4 d+4 c v+4 b v^3+4 a v^4-v w+w^2]=!=0. && 
   N[v]=!=0.)

continuFracP3[z_,{a_,b_,c_,d_},{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP3[{a,b,c,d},{v,w}]];

alphaListP3[{a_,b_,c_,d_},{v_,w_}]:=
  alphaListP3[{a,b,c,d},{v,w}]=
    Module[{n,nMax,spA,spB,spC,spD,spV,spW,listA,listB,listC,listD,
     listE,listF,listG,listH,listI,listJ,listK,listL,g0,h0,alpha,alphaList},
      n=1;
      nMax=2000;
      spA=SetPrecision[a,6500];
      spB=SetPrecision[b,6500];
      spC=SetPrecision[c,6500];
      spD=SetPrecision[d,6500];
      spV=SetPrecision[v,6500];
      spW=SetPrecision[w,6500];
      listA={0,0,spV,spV+spW,spW,0,0,0,0,0,0,0,0,0};
      listB={0,0,0,0,1,1,0,0,0,0,0,0,0,0};
      listC={0,0,0,0,0,0,0,0,0,0,0,0,0,0};
      listD={0,4 spV,5 spV+2 spW,3 spW,0,0,0,0,0,0,0,0,0,0};
      listE={0,0,0,0,1,0,0,0,0,0,0,0,0,0};
      listF={0,0,0,0,0,0,0,0,0,0,0,0,0,0};
      listG={-4 spD-4 spC spV-4 spB spV^3-4 spA spV^4+spV spW-spW^2,
        -4 (spD+2 spB spV^3+5 spA spV^4+spC spW+3 spB spV^2 spW+4 spA spV^3 spW),
        -4 spV (spB spV^2+10 spA spV^3+6 spB spV spW+20 spA spV^2 spW+
        3 spB spW^2+6 spA spV spW^2),
        -4 (10 spA spV^4+3 spB spV^2 spW+40 spA spV^3 spW+6 spB spV spW^2+
        30 spA spV^2 spW^2+spB spW^3+4 spA spV spW^3),
        -4 (5 spA spV^4+40 spA spV^3 spW+3 spB spV spW^2+60 spA spV^2 spW^2+
        2 spB spW^3+20 spA spV spW^3+spA spW^4),
        -4 (spA spV^4+20 spA spV^3 spW+60 spA spV^2 spW^2+spB spW^3+
        40 spA spV spW^3+5 spA spW^4),
        -8 spA spW (2 spV^3+15 spV^2 spW+20 spV spW^2+5 spW^3),
        -8 spA spW^2 (3 spV^2+10 spV spW+5 spW^2),-4 spA spW^3 (4 spV+5 spW),
        -4 spA spW^4,0,0,0,0};
      listH={2 spV,2 (2 spV-spW),-4 spC-12 spB spV^2-16 spA spV^3+spW,
        -8 spV (3 spB spV+10 spA spV^2+3 spB spW+6 spA spV spW),
        -4 (3 spB spV^2+40 spA spV^3+12 spB spV spW+60 spA spV^2 spW+
        3 spB spW^2+12 spA spV spW^2),
        -8 (20 spA spV^3+3 spB spV spW+60 spA spV^2 spW+3 spB spW^2+
        30 spA spV spW^2+2 spA spW^3),
        -4 (20 spA spV^3+120 spA spV^2 spW+3 spB spW^2+120 spA spV spW^2+
        20 spA spW^3),
        -16 spA (spV^3+15 spV^2 spW+30 spV spW^2+10 spW^3),
        -16 spA spW (3 spV^2+15 spV spW+10 spW^2),
        -16 spA spW^2 (3 spV+5 spW),-16 spA spW^3,0,0,0};
      listI={0,0,-2,0,-12 spV (spB+2 spA spV),
        -12 (2 spB spV+10 spA spV^2+spB spW+4 spA spV spW),
        -12 (spB spV+20 spA spV^2+2 spB spW+20 spA spV spW+2 spA spW^2),
        -12 (20 spA spV^2+spB spW+40 spA spV spW+10 spA spW^2),
        -120 spA (spV^2+4 spV spW+2 spW^2),
        -24 spA (spV^2+10 spV spW+10 spW^2),-24 spA spW (2 spV+5 spW),
        -24 spA spW^2,0,0};
      listJ={0,0,0,0,0,0,-4 (spB+4 spA spV),-8 (spB+10 spA spV+2 spA spW),
        -4 (spB+40 spA spV+20 spA spW),-160 spA (spV+spW),
        -80 spA (spV+2 spW),-16 spA (spV+5 spW),-16 spA spW,0};
      listK={0,0,0,0,0,0,0,0,-4 spA,-20 spA,-40 spA,-40 spA,-20 spA,-4 spA};
      listL={0,0,0,0,-1,-1,0,0,0,0,0,0,0,0};
      alpha=(4*spD+4*spC*spV+4*spB*spV^3+4*spA*spV^4-spV*spW+spW^2)/(2*spV);
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
        listK,listL,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-listB*alpha-listC*alpha^2,{0,0,0}],
         Join[{0},-2*listA-listB*alpha,{0,0}],
         Join[{0,0},-listA,{0}],
         Join[-listD-alpha*listE-alpha^2*listF,{0,0,0}]+
           Join[Drop[-2*listA-2*alpha*listB-2*alpha^2*listC,1],{0,0,0,0}],
         Join[2*alpha*listB+2*alpha*listL,{0,0,0}]+
           Join[{0},-2*listD-alpha*listE,{0,0}],
         Join[{0},2*listA,{0,0}]+Join[{0,0},-listD,{0}],
         g0=Join[Drop[listH+listG/alpha+listI*alpha+listJ*alpha^2+
           listK*alpha^3,1],{0,0,0,0}],
         h0=Join[4*listG/alpha+3*listH+2*alpha*listI+alpha^2*listJ,{0,0,0}]+
           Join[Drop[-listD-alpha*listE-alpha^2*listF,1],{0,0,0,0}],
         Join[-2*listD-alpha*listE,{0,0,0}]+
           Join[{0},6*listG/alpha+3*listH+alpha*listI,{0,0}]+
           Join[Drop[2*listA+2*alpha*listB+alpha*listL,1],{0,0,0,0}],
         Join[2*listA,{0,0,0}]+Join[{0},-listD,{0,0}]+
           Join[{0,0},4*listG/alpha+listH,{0}],
         Join[{0,0,0},listG/alpha],
         Join[{0},2*listA+2*listB*alpha+listL*alpha,{0,0}]},{n,nMax}],
         -1*g0[[1]]/h0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
          listK,listL,g0,h0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                  PainleveP3Exp[z,{a,b,c,d},{v,w}]                  *)
(**********************************************************************)

PainleveP3Exp[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  v0+v1*z+(v1^2/v0/2+(v0^3*a+v0^2*b+c+d/v0)/8)/
  continuFracP3Exp[z,{a,b,c,d},{v0,v1}]*z^2/;
  (Precision[z]<Infinity && N[v1^2/v0/2+(v0^3*a+v0^2*b+c+d/v0)/8]=!=0. && 
   N[v0]=!=0.)

continuFracP3Exp[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP3Exp[{a,b,c,d},{v0,v1}]];

alphaListP3Exp[{a_,b_,c_,d_},{v0_,v1_}]:=
  alphaListP3Exp[{a,b,c,d},{v0,v1}]=
    Module[{n,nMax,spA,spB,spC,spD,sp0,sp1,expTerm,exp2Term,x,
     listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
     listK,listL,g0,h0,alpha,alphaList},
      n=1;
      nMax=2000;
      spA=SetPrecision[a,7500];
      spB=SetPrecision[b,7500];
      spC=SetPrecision[c,7500];
      spD=SetPrecision[d,7500];
      sp0=SetPrecision[v0,7500];
      sp1=SetPrecision[v1,7500];
      expTerm=CoefficientList[Normal[Series[Exp[x],{x,0,nMax+20}]],x];
      exp2Term=CoefficientList[Normal[Series[Exp[2 x],{x,0,nMax+20}]],x];
      listA=Join[{0,0,sp0,sp1},Table[0,{nMax+17}]];
      listB=Join[{0,0,0,0,1},Table[0,{nMax+16}]];
      listC=Table[0,{nMax+21}];
      listD=Join[{0,4*sp0,2*sp1},Table[0,{nMax+18}]];
      listE=Table[0,{nMax+21}];
      listF=Table[0,{nMax+21}];
      listG=Join[{-sp1^2-sp0^4*spA/4-sp0^3*spB/4,-sp0^3*sp1*spA-3/4*sp0^2*sp1*spB,
        -3/2*sp0^2*sp1^2*spA-3/4*sp0*sp1^2*spB,-sp0*sp1^3*spA-sp1^3*spB/4,
        -sp1^4*spA/4},Table[0,{nMax+16}]]-sp0*spC/4*expTerm-spD/4*exp2Term+
        Drop[Join[{0},-sp1*spC/4*expTerm],-1];
      listH=Join[{2*sp0,-2*sp1,-sp0^3*spA-3/4*sp0^2*spB,-3*sp0^2*sp1*spA-
        3/2*sp0*sp1*spB,-3*sp0*sp1^2*spA-3/4*sp1^2*spB,-sp1^3*spA},
        Table[0,{nMax+15}]]+Drop[Join[{0,0},-spC/4*expTerm],-2];
      listI=Join[{0,0,-2,0,-3/2*sp0^2*spA-3/4*sp0*spB,-3*sp0*sp1*spA-3/4*sp1*spB,
        -3/2*sp1^2*spA},Table[0,{nMax+14}]];
      listJ=Join[{0,0,0,0,0,0,-sp0*spA-spB/4,-sp1*spA},Table[0,{nMax+13}]];
      listK=Join[{0,0,0,0,0,0,0,0,-spA/4},Table[0,{nMax+12}]];
      listL=Join[{0,0,0,0,-1},Table[0,{nMax+16}]];
      alpha=sp1^2/sp0/2+(sp0^3*spA+sp0^2*spB+spC+spD/sp0)/8;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
       listK,listL,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-listB*alpha-listC*alpha^2,{0,0,0}],
         Join[{0},-2*listA-listB*alpha,{0,0}],
         Join[{0,0},-listA,{0}],
         Join[-listD-alpha*listE-alpha^2*listF,{0,0,0}]+
           Join[Drop[-2*listA-2*alpha*listB-2*alpha^2*listC,1],{0,0,0,0}],
         Join[2*alpha*listB+2*alpha*listL,{0,0,0}]+
           Join[{0},-2*listD-alpha*listE,{0,0}],
         Join[{0},2*listA,{0,0}]+Join[{0,0},-listD,{0}],
         g0=Join[Drop[listH+listG/alpha+listI*alpha+listJ*alpha^2+listK*alpha^3,1],
           {0,0,0,0}],
         h0=Join[4*listG/alpha+3*listH+2*alpha*listI+alpha^2*listJ,{0,0,0}]+
           Join[Drop[-listD-alpha*listE-alpha^2*listF,1],{0,0,0,0}],
         Join[-2*listD-alpha*listE,{0,0,0}]+
           Join[{0},6*listG/alpha+3*listH+alpha*listI,{0,0}]+
           Join[Drop[2*listA+2*alpha*listB+alpha*listL,1],{0,0,0,0}],
         Join[2*listA,{0,0,0}]+Join[{0},-listD,{0,0}]+
           Join[{0,0},4*listG/alpha+listH,{0}],
         Join[{0,0,0},listG/alpha],
         Join[{0},2*listA+2*listB*alpha+listL*alpha,{0,0}]},{n,nMax}],
         -1*g0[[1]]/h0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[expTerm,exp2Term,listA,listB,listC,listD,listE,listF,listG,listH,
          listI,listJ,listK,listL,g0,h0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                     PainleveP4[z,{a,b},{v,w}]                      *)
(**********************************************************************)

PainleveP4[z_,{a_,b_},{v_,w_}]:=
  v+w*z+((a-2*b*v^2+3*v^4/2+w^2/2)/(2*v))/
  continuFracP4[z,{a,b},{v,w}]*z^2/;
  (Precision[z]<Infinity && N[a-2*b*v^2+3*v^4/2+w^2/2]=!=0. && N[v]=!=0.)

continuFracP4[z_,{a_,b_},{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP4[{a,b},{v,w}]];

alphaListP4[{a_,b_},{v_,w_}]:=
  alphaListP4[{a,b},{v,w}]=
    Module[{n,nMax,spA,spB,spV,spW,listA,listB,listC,listD,listE,listF,
     listG,listH,listI,listJ,listK,listL,g0,h0,alpha,alphaList},
      n=1;
      nMax=2400;
      spA=SetPrecision[a,5000];
      spB=SetPrecision[b,5000];
      spV=SetPrecision[v,5000];
      spW=SetPrecision[w,5000];
      listA={0,0,spV,spW,0,0,0,0,0};
      listB={0,0,0,0,1,0,0,0,0};
      listC={0,0,0,0,0,0,0,0,0};
      listD={0,4*spV,3*spW,0,0,0,0,0,0};
      listE={0,0,0,2,0,0,0,0,0};
      listF={0,0,0,0,0,0,0,0,0};
      listG={-spA+2*spB*spV^2-3/2*spV^4-spW^2/2,spV^3*(-4-6*spW)+4*spB*spV*spW,
        2*spB*spW^2+spV^2*(-2-12*spW-9*spW^2),spV*(-4*spW-12*spW^2-6*spW^3),
        -2*spW^2-4*spW^3-3/2*spW^4,0,0,0,0};
      listH={2*spV,0,4*spB*spV-6*spV^3,-12*spV^2+4*spB*spW-18*spV^2*spW,
        -4*spV-24*spV*spW-18*spV*spW^2,-4*spW-12*spW^2-6*spW^3,0,0,0};
      listI={0,0,0,0,2*spB-9*spV^2,-12*spV-18*spV*spW,-2-12*spW-9*spW^2,0,0};
      listJ={0,0,0,0,0,0,-6*spV,-4-6*spW,0};
      listK={0,0,0,0,0,0,0,0,-3/2};
      listL={0,0,0,0,-1/2,0,0,0,0};
      alpha=(spA-2*spB*spV^2+3*spV^4/2+spW^2/2)/(2*spV);
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
        alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-listB*alpha-listC*alpha^2,{0,0,0}],
         Join[{0},-2*listA-listB*alpha,{0,0}],
         Join[{0,0},-listA,{0}],
         Join[-listD-alpha*listE-alpha^2*listF,{0,0,0}]+
           Join[Drop[-2*listA-2*alpha*listB-2*alpha^2*listC,1],{0,0,0,0}],
         Join[2*alpha*listB+2*alpha*listL,{0,0,0}]+
           Join[{0},-2*listD-alpha*listE,{0,0}],
         Join[{0},2*listA,{0,0}]+Join[{0,0},-listD,{0}],
         g0=Join[Drop[listH+listG/alpha+listI*alpha+listJ*alpha^2+
           listK*alpha^3,1],{0,0,0,0}],
         h0=Join[4*listG/alpha+3*listH+2*alpha*listI+alpha^2*listJ,{0,0,0}]+
           Join[Drop[-listD-alpha*listE-alpha^2*listF,1],{0,0,0,0}],
         Join[-2*listD-alpha*listE,{0,0,0}]+
           Join[{0},6*listG/alpha+3*listH+alpha*listI,{0,0}]+
           Join[Drop[2*listA+2*alpha*listB+alpha*listL,1],{0,0,0,0}],
         Join[2*listA,{0,0,0}]+Join[{0},-listD,{0,0}]+
           Join[{0,0},4*listG/alpha+listH,{0}],
         Join[{0,0,0},listG/alpha],
         Join[{0},2*listA+2*listB*alpha+listL*alpha,{0,0}]},{n,nMax}],
         -1*g0[[1]]/h0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,
          listL,g0,h0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                   PainleveP5[z,{a,b,c,d},{v,w}]                    *)
(**********************************************************************)

PainleveP5[z_,{a_,b_,c_,d_},{v_,w_}]:=
  painleveP5Quad[Sqrt[z],{a,b,c,d},{v,2 w}];

PainleveP5Alternative[z_,{a_,b_,c_,d_},{v_,w_}]:=
  Module[{pp5},
    pp5=PainleveP5[z,{a,b,c,d},{v/(v-1),-w/((v-1)^2)}];
    pp5/(pp5-1)];

painleveP5Quad[z_,{a_,b_,c_,d_},{v_,w_}]:=
  v+w*(z-1)+((8*b*(v-1)^3+8*v^2*(-c+d+a*(v-1)^3+(c+d)*v)-2*(v-1)*v*w+(3*v-1)*w^2)/
  (4*(v-1)*v))/continuFracP5[(z-1),{a,b,c,d},{v,w}]*(z-1)^2/;
  (Precision[z]<Infinity && N[8*b*(v-1)^3+8*v^2*(-c+d+a*(v-1)^3+(c+d)*v)-
  2*(v-1)*v*w+(3*v-1)*w^2]=!=0. && N[v*(v-1)]=!=0.)

continuFracP5[z_,{a_,b_,c_,d_},{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP5[{a,b,c,d},{v,w}]];

alphaListP5[{a_,b_,c_,d_},{v_,w_}]:=
  alphaListP5[{a,b,c,d},{v,w}]=
    Module[{n,nMax,spA,spB,spC,spD,spV,spW,listA,listB,listC,listD,listE,
        listF,listG,listH,listI,listJ,listK,listL,listM,listN,listO,listP,
        K0,L0,alpha,alphaList},
      n=1;
      nMax=2000;
      spA=SetPrecision[a,6800];
      spB=SetPrecision[b,6800];
      spC=SetPrecision[c,6800];
      spD=SetPrecision[d,6800];
      spV=SetPrecision[v,6800];
      spW=SetPrecision[w,6800];
      listA={0,0,(1-spV) spV,2 spV-2 spV^2+spW-2 spV spW,
             spV-spV^2+2 spW-4 spV spW-spW^2,spW (1-2 spV-2 spW),
             -spW^2,0,0,0,0};
      listB={0,0,0,0,1-2 spV,2 (1-2 spV-spW),1-2 spV-4 spW,-2 spW,0,0,0};
      listC={0,0,0,0,0,0,-1,-2,-1,0,0};
      listD={0,0,0,0,0,0,0,0,0,0,0};
      listE={0,4 (1-spV) spV,9 spV-9 spV^2+3 spW-5 spV spW,
             5 spV-5 spV^2+7 spW-12 spV spW-spW^2,spW (4-7 spV-3 spW),
             -2 spW^2,0,0,0,0,0};
      listF={0,0,0,2 (1-spV),5-6 spV+spW,3-4 spV,-spW,0,0,0,0};
      listG={0,0,0,0,0,2,3,1,0,0,0};
      listH={0,0,0,0,0,0,0,0,0,0,0};
      listI={0,0,0,0,(3 spV-1)/2,(6 spV+3 spW-2)/2,
            (3 spV+6 spW-1)/2,3/2*spW,0,0,0};
      listJ={0,0,0,0,0,0,3/2,3,3/2,0,0};
      listK={(-8 spB+24 spB spV-8 spA spV^2-24 spB spV^2-8 spC spV^2+
               8 spD spV^2+24 spA spV^3+8 spB spV^3+8 spC spV^3+
               8 spD spV^3-24 spA spV^4+8 spA spV^5+2 spV spW-
               2 spV^2 spW-spW^2+3 spV spW^2)/2,
             (-16 spC spV^2+32 spD spV^2+16 spC spV^3+32 spD spV^3+24 spB spW+
               2 spV spW-16 spA spV spW-48 spB spV spW-16 spC spV spW+
               16 spD spV spW-2 spV^2 spW+72 spA spV^2 spW+24 spB spV^2 spW+
               24 spC spV^2 spW+24 spD spV^2 spW-96 spA spV^3 spW+
               40 spA spV^4 spW+2 spV spW^2+3 spW^3)/2,
             (-8 spC spV^2+48 spD spV^2+8 spC spV^3+48 spD spV^3-
               32 spC spV spW+64 spD spV spW+48 spC spV^2 spW+96 spD spV^2 spW+
               spW^2-8 spA spW^2-24 spB spW^2-8 spC spW^2+8 spD spW^2-
               spV spW^2+72 spA spV spW^2+24 spB spV spW^2+24 spC spV spW^2+
               24 spD spV spW^2-144 spA spV^2 spW^2+80 spA spV^3 spW^2+4 spW^3)/2,
             (32 spD spV^2+32 spD spV^3-16 spC spV spW+96 spD spV spW+
               24 spC spV^2 spW+144 spD spV^2 spW-16 spC spW^2+32 spD spW^2+
               48 spC spV spW^2+96 spD spV spW^2+spW^3+24 spA spW^3+8 spB spW^3+
               8 spC spW^3+8 spD spW^3-96 spA spV spW^3+80 spA spV^2 spW^3)/2,
             4 (spD spV^2+spD spV^3+8 spD spV spW+12 spD spV^2 spW-spC spW^2+
               6 spD spW^2+3 spC spV spW^2+18 spD spV spW^2+2 spC spW^3+
               4 spD spW^3-3 spA spW^4+5 spA spV spW^4),
             4 spW (2 spD spV+3 spD spV^2+4 spD spW+12 spD spV spW+spC spW^2+
               6 spD spW^2+spA spW^4),4 spD spW^2 (1+3 spV+4 spW),4 spD spW^3,
               0,0,0};
      listL={2 (1-spV) spV,2 spV (3-3 spV+spW),
               (24 spB+8 spV-16 spA spV-48 spB spV-16 spC spV+16 spD spV-
               8 spV^2+72 spA spV^2+24 spB spV^2+24 spC spV^2+24 spD spV^2-
               96 spA spV^3+40 spA spV^4+6 spW-4 spV spW+11 spW^2)/2,
             -16 spC spV+32 spD spV+24 spC spV^2+48 spD spV^2+3 spW-
               8 spA spW-24 spB spW-8 spC spW+8 spD spW-4 spV spW+
               72 spA spV spW+24 spB spV spW+24 spC spV spW+24 spD spV spW-
               144 spA spV^2 spW+80 spA spV^3 spW+7 spW^2,
             (-16 spC spV+96 spD spV+24 spC spV^2+144 spD spV^2-32 spC spW+
               64 spD spW+96 spC spV spW+192 spD spV spW+3 spW^2+72 spA spW^2+
               24 spB spW^2+24 spC spW^2+24 spD spW^2-288 spA spV spW^2+
               240 spA spV^2 spW^2)/2,
             8 (4 spD spV+6 spD spV^2-spC spW+6 spD spW+3 spC spV spW+
               18 spD spV spW+3 spC spW^2+6 spD spW^2-6 spA spW^3+10 spA spV spW^3),
             4 (2 spD spV+3 spD spV^2+8 spD spW+24 spD spV spW+3 spC spW^2+
               18 spD spW^2+5 spA spW^4),
             8 spD spW (1+3 spV+6 spW),12 spD spW^2,0,0};
      listM={0,0,2 spV,2 (1+4 spW),
             2-4 spA-12 spB-4 spC+4 spD-2 spV+36 spA spV+12 spB spV+
               12 spC spV+12 spD spV-72 spA spV^2+40 spA spV^3+11 spW,
             -8 spC+16 spD+24 spC spV+48 spD spV+3 spW+36 spA spW+12 spB spW+
               12 spC spW+12 spD spW-144 spA spV spW+120 spA spV^2 spW,
             4 (-spC+6 spD+3 spC spV+18 spD spV+6 spC spW+12 spD spW-
               18 spA spW^2+30 spA spV spW^2),
             4 (4 spD+12 spD spV+3 spC spW+18 spD spW+10 spA spW^3),
             4 spD (1+3 spV+12 spW),12 spD spW,0};
      listN={0,0,0,0,4,6,
             2 (1+6 spA+2 spB+2 spC+2 spD-24 spA spV+20 spA spV^2),
             8 (spC+2 spD-6 spA spW+10 spA spV spW),
             4 (spC+6 spD+10 spA spW^2),
             16 spD,4 spD};
      listO={0,0,0,0,0,0,0,0,4 spA (5 spV-3),20 spA spW,0};
      listP={0,0,0,0,0,0,0,0,0,0,4 spA};
      alpha=(8*spB*(spV-1)^3+8*spV^2*(-spC+spD+spA*(spV-1)^3+(spC+spD)*spV)-
             2*(spV-1)*spV*spW+(3*spV-1)*spW^2)/(4*(spV-1)*spV);
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
       listM,listN,listO,listP,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB-alpha^2*listC-alpha^3*listD,{0,0,0,0}],
         Join[{0},-3*listA-2*alpha*listB-alpha^2*listC,{0,0,0}],
         Join[{0,0},-3*listA-alpha*listB,{0,0}],
         Join[{0,0,0},-listA,{0}],
         Join[-listE-alpha*listF-alpha^2*listG-alpha^3*listH,{0,0,0,0}]-
           Join[Drop[2*listA+2*alpha*listB+2*alpha^2*listC+2*alpha^3*listD,1],
           {0,0,0,0,0}],
         Join[-2*listA+2*alpha^2*listC+2*alpha*listI+2*alpha^2*listJ,{0,0,0,0}]-
           Join[{0},3*listE+2*alpha*listF+alpha^2*listG,{0,0,0}],
         Join[{0},2*listA+2*alpha*listB+2*alpha*listI,{0,0,0}]-
           Join[{0,0},3*listE+alpha*listF,{0,0}],
         Join[{0,0},2*listA,{0,0}]-Join[{0,0,0},listE,{0}],
         Join[{0},2*listA+2*alpha*listB+2*alpha^2*listC+alpha*listI+alpha^2*listJ,
           {0,0,0}],
         Join[{0,0},4*listA+2*alpha*listB+alpha*listI,{0,0}],
         K0=Join[Drop[listK/alpha+listL+alpha*listM+alpha^2*listN+alpha^3*listO+
           alpha^4*listP,1],{0,0,0,0,0}],
         L0=Join[5*listK/alpha+4*listL+3*alpha*listM+2*alpha^2*listN+alpha^3*listO,
           {0,0,0,0}]-Join[Drop[listE+alpha*listF+alpha^2*listG+alpha^3*listH,1],
           {0,0,0,0,0}],
         Join[{0},10*listK/alpha+6*listL+3*alpha*listM+alpha^2*listN,{0,0,0}]-
           Join[3*listE+2*alpha*listF+alpha^2*listG,{0,0,0,0}]+
           Join[Drop[2*listA+2*alpha*listB+2*alpha^2*listC+alpha*listI+
           alpha^2*listJ,1],{0,0,0,0,0}],
         Join[4*listA+2*alpha*listB+alpha*listI,{0,0,0,0}]-
           Join[{0},3*listE+alpha*listF,{0,0,0}]+
           Join[{0,0},10*listK/alpha+4*listL+alpha*listM,{0,0}],
         Join[{0},2*listA,{0,0,0}]-Join[{0,0},listE,{0,0}]+
           Join[{0,0,0},5 listK/alpha+listL,{0}],
         Join[{0,0,0,0},listK/alpha]},{n,nMax}],
         -1*K0[[1]]/L0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
          listM,listN,listO,listP,K0,L0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                  PainleveP5Exp[z,{a,b,c,d},{v,w}]                  *)
(**********************************************************************)

PainleveP5Exp[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  v0+v1*z+((v1^2*(3-1/v0)/4+(3*v0^2*a-v0*a-3*v0^3*a+v0^4*a+3*b-3*v0*b+v0^2*b-
  v0*c+v0^2*c+v0*d+v0^2*d-b/v0)/2)/(v0-1))/
  continuFracP5Exp[z,{a,b,c,d},{v0,v1}]*z^2/;
  (Precision[z]<Infinity && N[v1^2*(3-1/v0)/4+(3*v0^2*a-v0*a-3*v0^3*a+v0^4*a+3*b-
   3*v0*b+v0^2*b-v0*c+v0^2*c+v0*d+v0^2*d-b/v0)/2]=!=0. && N[v0*(v0-1)]=!=0.)

continuFracP5Exp[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP5Exp[{a,b,c,d},{v0,v1}]];

alphaListP5Exp[{a_,b_,c_,d_},{v0_,v1_}]:=
  alphaListP5Exp[{a,b,c,d},{v0,v1}]=
    Module[{n,nMax,spA,spB,spC,spD,sp0,sp1,expTerm,exp2Term,x,listA,listB,listC,
       listD,listE,listF,listG,listH,listI,listJ,listK,listL,listM,listN,listO,
       listP,K0,L0,alpha,alphaList},
      n=1;
      nMax=2000;
      spA=SetPrecision[a,7500];
      spB=SetPrecision[b,7500];
      spC=SetPrecision[c,7500];
      spD=SetPrecision[d,7500];
      sp0=SetPrecision[v0,7500];
      sp1=SetPrecision[v1,7500];
      expTerm=CoefficientList[Normal[Series[Exp[x],{x,0,nMax+20}]],x];
      exp2Term=CoefficientList[Normal[Series[Exp[2 x],{x,0,nMax+20}]],x];
      listA=Join[{0,0,sp0^2-sp0,2*sp0*sp1-sp1,sp1^2},Table[0,{nMax+16}]];
      listB=Join[{0,0,0,0,2*sp0-1,2*sp1},Table[0,{nMax+15}]];
      listC=Join[{0,0,0,0,0,0,1},Table[0,{nMax+14}]];
      listD=Table[0,{nMax+21}];
      listE=Join[{0,4*sp0^2-4*sp0,5*sp0*sp1-3*sp1,sp1^2},Table[0,{nMax+17}]];
      listF=Join[{0,0,0,2*sp0-2,-sp1},Table[0,{nMax+16}]];
      listG=Join[{0,0,0,0,0,-2},Table[0,{nMax+15}]];
      listH=Table[0,{nMax+21}];
      listI=Join[{0,0,0,0,(1-3*sp0)/2,-3/2*sp1},Table[0,{nMax+15}]];
      listJ=Join[{0,0,0,0,0,0,-3/2},Table[0,{nMax+14}]];
      listK=Join[{sp1^2/2-3/2*sp0*sp1^2+sp0^2*spA-3*sp0^3*spA+3*sp0^4*spA-sp0^5*spA+
        spB-3*sp0*spB+3*sp0^2*spB-sp0^3*spB,
        -3/2*sp1^3+2*sp0*sp1*spA-9*sp0^2*sp1*spA+12*sp0^3*sp1*spA-5*sp0^4*sp1*spA-
        3*sp1*spB+6*sp0*sp1*spB-3*sp0^2*sp1*spB,
        sp1^2*spA-9*sp0*sp1^2*spA+18*sp0^2*sp1^2*spA-10*sp0^3*sp1^2*spA+3*sp1^2*spB-
        3*sp0*sp1^2*spB,
        -3*sp1^3*spA+12*sp0*sp1^3*spA-10*sp0^2*sp1^3*spA-sp1^3*spB,
        3*sp1^4*spA-5*sp0*sp1^4*spA,-sp1^5*spA},Table[0,{nMax+15}]]+
        (1-sp0)*sp0^2*spC*expTerm-(1+sp0)*sp0^2*spD*exp2Term+
        Drop[Join[{0},(2-3*sp0)*sp0*sp1*spC*expTerm-(2+3*sp0)*sp0*sp1*spD*exp2Term],-1]+
        Drop[Join[{0,0},(1-3*sp0)*sp1^2*spC*expTerm-(1+3*sp0)*sp1^2*spD*exp2Term],-2]+
        Drop[Join[{0,0,0},-sp1^3*(spC*expTerm+spD*exp2Term)],-3];
      listL=Join[{-2*sp0+2*sp0^2,-2*sp0*sp1,
        -11/2*sp1^2+2*sp0*spA-9*sp0^2*spA+12*sp0^3*spA-5*sp0^4*spA-3*spB+6*sp0*spB-
        3*sp0^2*spB,
        2*sp1*spA-18*sp0*sp1*spA+36*sp0^2*sp1*spA-20*sp0^3*sp1*spA+6*sp1*spB-
        6*sp0*sp1*spB,
        -9*sp1^2*spA+36*sp0*sp1^2*spA-30*sp0^2*sp1^2*spA-3*sp1^2*spB,
        12*sp1^3*spA-20*sp0*sp1^3*spA,-5*sp1^4*spA},Table[0,{nMax+14}]]+
        Drop[Join[{0,0},sp0*spC*(2-3*sp0)*expTerm-sp0*spD*(2+3*sp0)*exp2Term],-2]+
        Drop[Join[{0,0,0},sp1*spC*(2-6*sp0)*expTerm-sp1*spD*(2+6*sp0)*exp2Term],-3]+
        Drop[Join[{0,0,0,0},-3*sp1^2*(spC*expTerm+spD*exp2Term)],-4];
      listM=Join[{0,0,-2*sp0,-8*sp1,
        spA-9*sp0*spA+18*sp0^2*spA-10*sp0^3*spA+3*spB-3*sp0*spB,
        -9*sp1*spA+36*sp0*sp1*spA-30*sp0^2*sp1*spA-3*sp1*spB,
        18*sp1^2*spA-30*sp0*sp1^2*spA,-10*sp1^3*spA},Table[0,{nMax+13}]]+
        Drop[Join[{0,0,0,0},(spC-3*sp0*spC)*expTerm-(spD+3*sp0*spD)*exp2Term],-4]+
        Drop[Join[{0,0,0,0,0},-3*sp1*spC*expTerm-3*sp1*spD*exp2Term],-5];
      listN=Join[{0,0,0,0,-4,0,12*sp0*spA-3*spA-10*sp0^2*spA-spB,
        12*sp1*spA-20*sp0*sp1*spA,-10*sp1^2*spA},Table[0,{nMax+12}]]+
        Drop[Join[{0,0,0,0,0,0},-spC*expTerm-spD*exp2Term],-6];
      listO=Join[{0,0,0,0,0,0,0,0,3*spA-5*sp0*spA,-5*sp1*spA},Table[0,{nMax+11}]];
      listP=Join[{0,0,0,0,0,0,0,0,0,0,-spA},Table[0,{nMax+10}]];
      alpha=(sp1^2*(3-1/sp0)/4+(3*sp0^2*spA-sp0*spA-3*sp0^3*spA+sp0^4*spA+3*spB-
        3*sp0*spB+sp0^2*spB-sp0*spC+sp0^2*spC+sp0*spD+sp0^2*spD-spB/sp0)/2)/(sp0-1);
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
       listM,listN,listO,listP,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB-alpha^2*listC-alpha^3*listD,{0,0,0,0}],
         Join[{0},-3*listA-2*alpha*listB-alpha^2*listC,{0,0,0}],
         Join[{0,0},-3*listA-alpha*listB,{0,0}],
         Join[{0,0,0},-listA,{0}],
         Join[-listE-alpha*listF-alpha^2*listG-alpha^3*listH,{0,0,0,0}]-
           Join[Drop[2*listA+2*alpha*listB+2*alpha^2*listC+2*alpha^3*listD,1],
           {0,0,0,0,0}],
         Join[-2*listA+2*alpha^2*listC+2*alpha*listI+2*alpha^2*listJ,{0,0,0,0}]-
           Join[{0},3*listE+2*alpha*listF+alpha^2*listG,{0,0,0}],
         Join[{0},2*listA+2*alpha*listB+2*alpha*listI,{0,0,0}]-
           Join[{0,0},3*listE+alpha*listF,{0,0}],
         Join[{0,0},2*listA,{0,0}]-Join[{0,0,0},listE,{0}],
         Join[{0},2*listA+2*alpha*listB+2*alpha^2*listC+alpha*listI+alpha^2*listJ,
           {0,0,0}],
         Join[{0,0},4*listA+2*alpha*listB+alpha*listI,{0,0}],
         K0=Join[Drop[listK/alpha+listL+alpha*listM+alpha^2*listN+alpha^3*listO+
           alpha^4*listP,1],{0,0,0,0,0}],
         L0=Join[5*listK/alpha+4*listL+3*alpha*listM+2*alpha^2*listN+
           alpha^3*listO,{0,0,0,0}]-
           Join[Drop[listE+alpha*listF+alpha^2*listG+alpha^3*listH,1],{0,0,0,0,0}],
         Join[{0},10*listK/alpha+6*listL+3*alpha*listM+alpha^2*listN,{0,0,0}]-
           Join[3*listE+2*alpha*listF+alpha^2*listG,{0,0,0,0}]+
           Join[Drop[2*listA+2*alpha*listB+2*alpha^2*listC+alpha*listI+
           alpha^2*listJ,1],{0,0,0,0,0}],
         Join[4*listA+2*alpha*listB+alpha*listI,{0,0,0,0}]-
           Join[{0},3*listE+alpha*listF,{0,0,0}]+
           Join[{0,0},10*listK/alpha+4*listL+alpha*listM,{0,0}],
         Join[{0},2*listA,{0,0,0}]-Join[{0,0},listE,{0,0}]+
           Join[{0,0,0},5*listK/alpha+listL,{0}],
         Join[{0,0,0,0},listK/alpha]},{n,nMax}],
         -1*K0[[1]]/L0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[expTerm,exp2Term,listA,listB,listC,listD,listE,listF,listG,listH,listI,
          listJ,listK,listL,listM,listN,listO,listP,K0,L0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                   PainleveP6[z,{a,b,c,d},{v,w}]                    *)
(**********************************************************************)

PainleveP6[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  painleveP6Exp[Log[z/(1-z)],{a,b,c,d},{v0,v1/4}]/;
  (Precision[z]<Infinity)

painleveP6Exp[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  v0+v1*z+((2 v1^2-24 v0^5*a+8 v0^6*a+2 v0 (v1-6 v1^2-3 b)+b+
  v0^4*(26 a+4 b-4 c-2 d)+v0^2*(2 v1 (-1+6 v1)+2 a+13 b-c-2 d)+
  4 v0^3*(-3 a-3 b+c+d))/(8 (-1+v0) v0 (-1+2 v0)))/
  continuFracP6Exp[z,{a,b,c,d},{v0,v1}]*z^2/;
  (Precision[z]<Infinity && 
   N[2 v1^2-24 v0^5*a+8 v0^6*a+2 v0 (v1-6 v1^2-3 b)+b+v0^4*(26 a+4 b-4 c-2 d)+
   v0^2*(2 v1 (-1+6 v1)+2 a+13 b-c-2 d)+4 v0^3*(-3 a-3 b+c+d)]=!=0. && 
   N[8 (-1+v0) v0 (-1+2 v0)]=!=0.)

continuFracP6Exp[z_,{a_,b_,c_,d_},{v0_,v1_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListP6Exp[{a,b,c,d},{v0,v1}]];

alphaListP6Exp[{a_,b_,c_,d_},{v0_,v1_}]:=
  alphaListP6Exp[{a,b,c,d},{v0,v1}]=
  Module[{n,nMax,spA,spB,spC,spD,sp0,sp1,expTerm,exp2Term,exp3Term,k,
    listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
    listM,listN,listO,listP,listQ,listR,listS,listT,N0,O0,alpha,alphaList},
    n=1;
    nMax=2500;
    spA=SetPrecision[a,8500];
    spB=SetPrecision[b,8500];
    spC=SetPrecision[c,8500];
    spD=SetPrecision[d,8500];
    sp0=SetPrecision[v0,8500];
    sp1=SetPrecision[v1,8500];
    expTerm=Table[1/(k!),{k,0,nMax+20}];
    exp2Term=Table[2^k/(k!),{k,0,nMax+20}];
    exp3Term=Table[3^k/(k!),{k,0,nMax+20}];
    listA=Join[{0,0,-2 sp0^2+2 sp0^3,-4 sp0 sp1+6 sp0^2*sp1,-2 sp1^2+6 sp0 sp1^2,
      2 sp1^3},Table[0,{nMax+15}]]+
      Drop[Join[Table[0,{2}],2 (-1+sp0) sp0 (-1+3 sp0)*expTerm+
      2 (-1+sp0) sp0 (-2+3 sp0)*exp2Term+2 (-1+sp0)^2*sp0*exp3Term],-2]+
      Drop[Join[Table[0,{3}],2 (1+sp0 (-8+9 sp0)) sp1*expTerm+
      2 (2+sp0 (-10+9 sp0)) sp1*exp2Term+2 (-1+sp0) (-1+3 sp0) sp1*exp3Term],-3]+
      Drop[Join[Table[0,{4}],2 (-4+9 sp0) sp1^2*expTerm+2 (-5+9 sp0) sp1^2*exp2Term+
      2 (-2+3 sp0) sp1^2*exp3Term],-4]+
      Drop[Join[Table[0,{5}],6 sp1^3*expTerm+6 sp1^3*exp2Term+2 sp1^3*exp3Term],-5];
    listB=Join[{0,0,0,0,-4 sp0+6 sp0^2,-4 sp1+12 sp0 sp1,6 sp1^2},Table[0,{nMax+14}]]+
      Drop[Join[Table[0,{4}],2 (1+sp0 (-8+9 sp0))*expTerm+
      (4+2 sp0 (-10+9 sp0))*exp2Term+(2-8 sp0+6 sp0^2)*exp3Term],-4]+
      Drop[Join[Table[0,{5}],4 (-4+9 sp0) sp1*expTerm+4 (-5+9 sp0) sp1*exp2Term+
      4 (-2+3 sp0) sp1*exp3Term],-5]+
      Drop[Join[Table[0,{6}],18 sp1^2*expTerm+18 sp1^2*exp2Term+6 sp1^2*exp3Term],-6];
    listC=Join[{0,0,0,0,0,0,-2+6 sp0,6 sp1},Table[0,{nMax+13}]]+
      Drop[Join[Table[0,{6}],(-8+18 sp0)*expTerm+2 (-5+9 sp0)*exp2Term+
      (-4+6 sp0)*exp3Term],-6]+
      Drop[Join[Table[0,{7}],18 sp1*expTerm+18 sp1*exp2Term+6 sp1*exp3Term],-7];
    listD=Join[{0,0,0,0,0,0,0,0,2},Table[0,{nMax+12}]]+
      Drop[Join[Table[0,{8}],6*expTerm+6*exp2Term+2*exp3Term],-8];
    listE=Table[0,{nMax+21}];
    listF=Join[{0,8 (-1+sp0) sp0^2,6 sp0 (-2+3 sp0) sp1,4 (-1+3 sp0) sp1^2,2 sp1^3},
      Table[0,{nMax+16}]]+Drop[Join[Table[0,{1}],8 (-1+sp0) sp0 (-1+3 sp0)*expTerm+
      8 (-1+sp0) sp0 (-2+3 sp0)*exp2Term+8 (-1+sp0)^2*sp0*exp3Term],-1]+
      Drop[Join[Table[0,{2}],(6 sp1+2 sp0 (-1+sp0+3 (-8+9 sp0) sp1))*expTerm+
      (2 (-1+sp0) sp0+6 (2+sp0 (-10+9 sp0)) sp1)*exp2Term+
      6 (-1+sp0) (-1+3 sp0) sp1*exp3Term],-2]+
      Drop[Join[Table[0,{3}],2 sp1 (-1-8 sp1+2 sp0 (1+9 sp1))*expTerm+
      2 sp1 (-1+2 sp0+2 (-5+9 sp0) sp1)*exp2Term+4 (-2+3 sp0) sp1^2*exp3Term],-3]+
      Drop[Join[Table[0,{4}],2 sp1^2*(1+3 sp1)*expTerm+2 sp1^2*(1+3 sp1)*exp2Term+
      2 sp1^3*exp3Term],-4];
    listG=Join[{0,0,0,4 sp0 (-2+3 sp0),4 (-1+3 sp0) sp1,0},Table[0,{nMax+15}]]+
      Drop[Join[Table[0,{3}],4 (1+sp0 (-8+9 sp0))*expTerm+
      (8+4 sp0 (-10+9 sp0))*exp2Term+4 (-1+sp0) (-1+3 sp0)*exp3Term],-3]+
      Drop[Join[Table[0,{4}],(-2+4 sp0-16 sp1+36 sp0 sp1)*expTerm+
      (-2-20 sp1+4 sp0 (1+9 sp1))*exp2Term+4 (-2+3 sp0) sp1*exp3Term],-4]+
      Drop[Join[Table[0,{5}],4 sp1*expTerm+4 sp1*exp2Term],-5];
    listH=Join[{0,0,0,0,0,0,-6 sp1},Table[0,{nMax+14}]]+
      Drop[Join[Table[0,{6}],(2-18 sp1)*expTerm+(2-18 sp1)*exp2Term-
      6 sp1*exp3Term],-6];
    listI=Join[{0,0,0,0,0,0,0,-4},Table[0,{nMax+13}]]+
      Drop[Join[Table[0,{7}],-12*expTerm-12*exp2Term-4*exp3Term],-7];
    listJ=Table[0,{nMax+21}];
    listK=Join[{0,0,0,0,(2-3 sp0) sp0,(2-6 sp0) sp1,-3 sp1^2},Table[0,{nMax+14}]]+
      Drop[Join[Table[0,{4}],(-1+(8-9 sp0) sp0)*expTerm+
      (-2+(10-9 sp0) sp0)*exp2Term+(-1+(4-3 sp0) sp0)*exp3Term],-4]+
      Drop[Join[Table[0,{5}],2 (4-9 sp0) sp1*expTerm+2 (5-9 sp0) sp1*exp2Term+
      (4-6 sp0) sp1*exp3Term],-5]+
      Drop[Join[Table[0,{6}],-9 sp1^2*expTerm-9 sp1^2*exp2Term-3 sp1^2*exp3Term],-6];
    listL=Join[{0,0,0,0,0,0,2-6 sp0,-6 sp1},Table[0,{nMax+13}]]+
      Drop[Join[Table[0,{6}],(8-18 sp0)*expTerm+(10-18 sp0)*exp2Term+
      (4-6 sp0)*exp3Term],-6]+
      Drop[Join[Table[0,{7}],-18 sp1*expTerm-18 sp1*exp2Term-6 sp1*exp3Term],-7];
    listM=Join[{0,0,0,0,0,0,0,0,-3},Table[0,{nMax+12}]]+
      Drop[Join[Table[0,{8}],-9*expTerm-9*exp2Term-3*exp3Term],-8];
    listN=Join[{sp0 ((2-3 sp0) sp1^2+2 sp0^3*(-(-1+sp0)^2*spA+spC)),
      2 sp1 ((1-3 sp0) sp1^2+2 sp0^3*((-2+(5-3 sp0) sp0) spA+2 spC)),
      sp1^2*(-3 sp1^2+2 sp0^2*((-6+5 (4-3 sp0) sp0) spA+6 spC)),
      8 sp0 sp1^3*((-1-5 (-1+sp0) sp0) spA+spC),
      2 sp1^4*((-1+5 (2-3 sp0) sp0) spA+spC),4 (1-3 sp0) sp1^5*spA,-2 sp1^6*spA},
      Table[0,{nMax+14}]]+(-sp1^2+2 sp0 sp1 (-1+4 sp1)+16 sp0^5*spA-
      6 sp0^6*spA+4 sp0^3*(spA+spB-spC-spD)+2 sp0^4*(-7 spA-spB+2 spC+spD)+
      sp0^2*((2-9 sp1) sp1-2 spB+2 spD))*expTerm+
      (-2 sp1^2+20 sp0^5*spA-6 sp0^6*spA+2 sp0 (sp1 (-1+5 sp1)+2 spB)+
      4 sp0^3*(3 spA+3 spB-spC-spD)+2 sp0^4*(-12 spA-2 spB+spC+spD)+
      sp0^2*((2-9 sp1) sp1+2 (-spA-6 spB+spC+spD)))*exp2Term-
      (-1+sp0) ((-1+3 sp0) sp1^2+2 (-1+sp0)^3*(sp0^2*spA+spB))*exp3Term+
      Drop[Join[Table[0,{1}],(-2 sp1 (sp1-2 sp0 sp1+(-4+9 sp0) sp1^2+
      2 sp0 (spB-spD+sp0 ((-1+sp0) (3+sp0 (-11+9 sp0)) spA+2 sp0 (spB-2 spC-spD)+
      3 (-spB+spC+spD)))))*expTerm+(-2 sp1 (sp1-2 sp0 sp1+(-5+9 sp0) sp1^2+
      2 (-1+sp0) (spB+sp0 ((-1+sp0) (1+sp0 (-7+9 sp0)) spA+(-5+4 sp0) spB+spC+spD-
      2 sp0 (spC+spD)))))*exp2Term-2 sp1 ((-2+3 sp0) sp1^2+
      2 (-1+sp0)^3*(sp0 (-1+3 sp0) spA+2 spB))*exp3Term],-1]+
      Drop[Join[Table[0,{2}],(sp1^2*((2-9 sp1) sp1-
      2 (spB-spD+sp0 ((-6+sp0 (42+5 sp0 (-16+9 sp0))) spA+6 ((-1+sp0) spB+spC+spD-
      sp0 (2 spC+spD))))))*expTerm+(sp1^2*((2-9 sp1) sp1-
      2 ((-1+sp0) (-1+sp0 (17+5 sp0 (-11+9 sp0))) spA+6 (-1+sp0) (-1+2 sp0) spB-
      (1+6 (-1+sp0) sp0) (spC+spD))))*exp2Term-
      sp1^2*(3 sp1^2+2 (-1+sp0)^2*((1+5 sp0 (-2+3 sp0)) spA+6 spB))*exp3Term],-2]+
      Drop[Join[Table[0,{3}],(-4 sp1^3*((-1+2 sp0 (7+5 sp0 (-4+3 sp0))) spA+
      (-1+2 sp0) spB+spC+spD-2 sp0 (2 spC+spD)))*expTerm+
      (-4 sp1^3*((-3+2 sp0 (12+5 sp0 (-5+3 sp0))) spA+(-3+4 sp0) spB+spC+spD-
      2 sp0 (spC+spD)))*exp2Term-
      8 (-1+sp0) sp1^3*((1+5 (-1+sp0) sp0) spA+spB)*exp3Term],-3]+
      Drop[Join[Table[0,{4}],2 sp1^4*((-7+5 (8-9 sp0) sp0) spA-spB+2 spC+spD)*expTerm+
      2 sp1^4*((-12+5 (10-9 sp0) sp0) spA-2 spB+spC+spD)*exp2Term-
      2 sp1^4*((6+5 sp0 (-4+3 sp0)) spA+spB)*exp3Term],-4]+
      Drop[Join[Table[0,{5}],4 (4-9 sp0) sp1^5*spA*expTerm+
      4 (5-9 sp0) sp1^5*spA*exp2Term+4 (2-3 sp0) sp1^5*spA*exp3Term],-5]+
      Drop[Join[Table[0,{6}],-6 sp1^6*spA*expTerm-6 sp1^6*spA*exp2Term-
      2 sp1^6*spA*exp3Term],-6];
    listO=Join[{4 (-1+sp0) sp0^2,0,(6-18 sp0) sp1^2+
      4 sp0^3*((-2+(5-3 sp0) sp0) spA+2 spC),
      -2 sp1 (7 sp1^2+2 sp0^2*((6+5 sp0 (-4+3 sp0)) spA-6 spC)),
      -24 sp0 sp1^2*((1+5 (-1+sp0) sp0) spA-spC),
      8 sp1^3*((-1+5 (2-3 sp0) sp0) spA+spC),20 (1-3 sp0) sp1^4*spA,-12 sp1^5*spA},
      Table[0,{nMax+13}]]+4 (-1+sp0) sp0 (-1+3 sp0)*expTerm+
      4 (-1+sp0) sp0 (-2+3 sp0)*exp2Term+4 (-1+sp0)^2*sp0*exp3Term+
      Drop[Join[Table[0,{1}],4 (-1+sp0) sp0*expTerm+4 (-1+sp0) sp0*exp2Term],-1]+
      Drop[Join[Table[0,{2}],(-2 ((3-6 sp0) sp1+3 (-4+9 sp0) sp1^2+
      2 sp0 (spB-spD+sp0 ((-1+sp0) (3+sp0 (-11+9 sp0)) spA+2 sp0 (spB-2 spC-spD)+
      3 (-spB+spC+spD)))))*expTerm+(-2 ((3-6 sp0) sp1+3 (-5+9 sp0) sp1^2+
      2 (-1+sp0) (spB+sp0 ((-1+sp0) (1+sp0 (-7+9 sp0)) spA+(-5+4 sp0) spB+spC+spD-
      2 sp0 (spC+spD)))))*exp2Term-2 ((-6+9 sp0) sp1^2+
      2 (-1+sp0)^3*(sp0 (-1+3 sp0) spA+2 spB))*exp3Term],-2]+
      Drop[Join[Table[0,{3}],(2 sp1 ((4-21 sp1) sp1-
      2 (spB-spD+sp0 ((-6+sp0 (42+5 sp0 (-16+9 sp0))) spA+6 ((-1+sp0) spB+spC+spD-
      sp0 (2 spC+spD))))))*expTerm+(2 sp1 ((4-21 sp1) sp1-
      2 ((-1+sp0) (-1+sp0 (17+5 sp0 (-11+9 sp0))) spA+6 (-1+sp0) (-1+2 sp0) spB-
      (1+6 (-1+sp0) sp0) (spC+spD))))*exp2Term-2 sp1 (7 sp1^2+
      2 (-1+sp0)^2*((1+5 sp0 (-2+3 sp0)) spA+6 spB))*exp3Term],-3]+
      Drop[Join[Table[0,{4}],(-12 sp1^2*((-1+2 sp0 (7+5 sp0 (-4+3 sp0))) spA+
      (-1+2 sp0) spB+spC+spD-2 sp0 (2 spC+spD)))*expTerm+
      (-12 sp1^2*((-3+2 sp0 (12+5 sp0 (-5+3 sp0))) spA+(-3+4 sp0) spB+spC+spD-
      2 sp0 (spC+spD)))*exp2Term-
      24 (-1+sp0) sp1^2*((1+5 (-1+sp0) sp0) spA+spB)*exp3Term],-4]+
      Drop[Join[Table[0,{5}],-8 sp1^3*((7+5 sp0 (-8+9 sp0)) spA+spB-2 spC-spD)*
      expTerm+8 sp1^3*((-12+5 (10-9 sp0) sp0) spA-2 spB+spC+spD)*exp2Term-
      8 sp1^3*((6+5 sp0 (-4+3 sp0)) spA+spB)*exp3Term],-5]+
      Drop[Join[Table[0,{6}],20 (4-9 sp0) sp1^4*spA*expTerm+
      20 (5-9 sp0) sp1^4*spA*exp2Term+20 (2-3 sp0) sp1^4*spA*exp3Term],-6]+
      Drop[Join[Table[0,{7}],-36 sp1^5*spA*expTerm-36 sp1^5*spA*exp2Term-
      12 sp1^5*spA*exp3Term],-7];
    listP=Join[{0,0,0,8 (1-3 sp0) sp1,
      -27 sp1^2+2 sp0^2*((-6+5 (4-3 sp0) sp0) spA+6 spC),
      -24 sp0 sp1 ((1+5 (-1+sp0) sp0) spA-spC),
      -12 sp1^2*((1+5 sp0 (-2+3 sp0)) spA-spC),
      40 (1-3 sp0) sp1^3*spA,-30 sp1^4*spA},Table[0,{nMax+12}]]+
      Drop[Join[Table[0,{3}],(-4+sp0 (8-72 sp1)+32 sp1)*expTerm+
      (-4+sp0 (8-72 sp1)+40 sp1)*exp2Term+8 (2-3 sp0) sp1*exp3Term],-3]+
      Drop[Join[Table[0,{4}],((10-81 sp1) sp1-
      2 (spB-spD+sp0 ((-6+sp0 (42+5 sp0 (-16+9 sp0))) spA+6 ((-1+sp0) spB+spC+spD-
      sp0 (2 spC+spD)))))*expTerm+((10-81 sp1) sp1-
      2 ((-1+sp0) (-1+sp0 (17+5 sp0 (-11+9 sp0))) spA+6 (-1+sp0) (-1+2 sp0) spB-
      (1+6 (-1+sp0) sp0) (spC+spD)))*exp2Term+
      (-27 sp1^2-2 (-1+sp0)^2*((1+5 sp0 (-2+3 sp0)) spA+6 spB))*exp3Term],-4]+
      Drop[Join[Table[0,{5}],(-12 sp1 ((-1+2 sp0 (7+5 sp0 (-4+3 sp0))) spA+
      (-1+2 sp0) spB+spC+spD-2 sp0 (2 spC+spD)))*expTerm+
      (-12 sp1 ((-3+2 sp0 (12+5 sp0 (-5+3 sp0))) spA+(-3+4 sp0) spB+spC+spD-
      2 sp0 (spC+spD)))*exp2Term-
      24 (-1+sp0) sp1 ((1+5 (-1+sp0) sp0) spA+spB)*exp3Term],-5]+
      Drop[Join[Table[0,{6}],-12 sp1^2*((7+5 sp0 (-8+9 sp0)) spA+spB-2 spC-spD)*
      expTerm-12 sp1^2*((12+5 sp0 (-10+9 sp0)) spA+2 spB-spC-spD)*exp2Term-
      12 sp1^2*((6+5 sp0 (-4+3 sp0)) spA+spB)*exp3Term],-6]+
      Drop[Join[Table[0,{7}],40 (4-9 sp0) sp1^3*spA*expTerm+
      40 (5-9 sp0) sp1^3*spA*exp2Term+40 (2-3 sp0) sp1^3*spA*exp3Term],-7]+
      Drop[Join[Table[0,{8}],-90 sp1^4*spA*expTerm-90 sp1^4*spA*exp2Term-
      30 sp1^4*spA*exp3Term],-8];
    listQ=Join[{0,0,0,0,4-12 sp0,-24 sp1,8 sp0 ((-1-5 (-1+sp0) sp0) spA+spC),
      8 sp1 ((-1+5 (2-3 sp0) sp0) spA+spC),40 (1-3 sp0) sp1^2*spA,-40 sp1^3*spA},
      Table[0,{nMax+11}]]+
      Drop[Join[Table[0,{4}],(16-36 sp0)*expTerm+(20-36 sp0)*exp2Term+(8-12 sp0)*
      exp3Term],-4]+
      Drop[Join[Table[0,{5}],(4-72 sp1)*expTerm+(4-72 sp1)*exp2Term-
      24 sp1*exp3Term],-5]+
      Drop[Join[Table[0,{6}],(-4 ((-1+2 sp0 (7+5 sp0 (-4+3 sp0))) spA+(-1+2 sp0)*
      spB+spC+spD-2 sp0 (2 spC+spD)))*expTerm+(-4 ((-3+2 sp0 (12+5 sp0 (-5+3 sp0)))*
      spA+(-3+4 sp0) spB+spC+spD-2 sp0 (spC+spD)))*exp2Term-
      8 (-1+sp0) ((1+5 (-1+sp0) sp0) spA+spB)*exp3Term],-6]+
      Drop[Join[Table[0,{7}],-8 sp1 ((7+5 sp0 (-8+9 sp0)) spA+spB-2 spC-spD)*
      expTerm+8 sp1 ((-12+5 (10-9 sp0) sp0) spA-2 spB+spC+spD)*exp2Term-
      8 sp1 ((6+5 sp0 (-4+3 sp0)) spA+spB)*exp3Term],-7]+
      Drop[Join[Table[0,{8}],40 (4-9 sp0) sp1^2*spA*expTerm+
      40 (5-9 sp0) sp1^2*spA*exp2Term+40 (2-3 sp0) sp1^2*spA*exp3Term],-8]+
      Drop[Join[Table[0,{9}],-120 sp1^3*spA*expTerm-120 sp1^3*spA*exp2Term-
      40 sp1^3*spA*exp3Term],-9];
    listR=Join[{0,0,0,0,0,0,-8,0,(-2+10 (2-3 sp0) sp0) spA+2 spC,
      20 (1-3 sp0) sp1 spA,-30 sp1^2*spA},Table[0,{nMax+10}]]+
      Drop[Join[Table[0,{6}],-24*expTerm-24*exp2Term-8*exp3Term],-6]+
      Drop[Join[Table[0,{8}],2 ((-7+5 (8-9 sp0) sp0) spA-spB+2 spC+spD)*expTerm+
      2 ((-12+5 (10-9 sp0) sp0) spA-2 spB+spC+spD)*exp2Term-
      2 ((6+5 sp0 (-4+3 sp0)) spA+spB)*exp3Term],-8]+
      Drop[Join[Table[0,{9}],20 (4-9 sp0) sp1 spA*expTerm+
      20 (5-9 sp0) sp1 spA*exp2Term+20 (2-3 sp0) sp1 spA*exp3Term],-9]+
      Drop[Join[Table[0,{10}],-90 sp1^2*spA*expTerm-90 sp1^2*spA*exp2Term-
      30 sp1^2*spA*exp3Term],-10];
    listS=Join[{0,0,0,0,0,0,0,0,0,0,4 (1-3 sp0) spA,-12 sp1 spA},
      Table[0,{nMax+9}]]+Drop[Join[Table[0,{10}],4 (4-9 sp0) spA*expTerm+
      4 (5-9 sp0) spA*exp2Term+4 (2-3 sp0) spA*exp3Term],-10]+
      Drop[Join[Table[0,{11}],-36 sp1 spA*expTerm-36 sp1 spA*exp2Term-
      12 sp1 spA*exp3Term],-11];
    listT=Join[{0,0,0,0,0,0,0,0,0,0,0,0,-2 spA},Table[0,{nMax+8}]]+
      Drop[Join[Table[0,{12}],-6 spA*expTerm-6 spA*exp2Term-2 spA*exp3Term],-12];
    alpha=(2 sp1^2-24 sp0^5*spA+8 sp0^6*spA+2 sp0 (sp1-6 sp1^2-3 spB)+spB+
      sp0^4*(26 spA+4 spB-4 spC-2 spD)+sp0^2*(2 sp1 (-1+6 sp1)+
      2 spA+13 spB-spC-2 spD)+4 sp0^3*(-3 spA-3 spB+spC+spD))/
      (8 (-1+sp0) sp0 (-1+2 sp0));
    alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
       listM,listN,listO,listP,listQ,listR,listS,listT,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha listB-alpha^2*listC-alpha^3*listD-alpha^4*listE,
           {0,0,0,0,0}],
         Join[{0},-4 listA-3 alpha listB-2 alpha^2*listC-alpha^3*listD,{0,0,0,0}],
         Join[{0,0},-6 listA-3 alpha listB-alpha^2*listC,{0,0,0}],
         Join[{0,0,0},-4 listA-alpha listB,{0,0}],
         Join[{0,0,0,0},-listA,{0}],
         Join[-listF-alpha (listG+alpha (listH+alpha (listI+alpha listJ))),
           {0,0,0,0,0}]-
           Join[Drop[2 (listA+alpha (listB+alpha (listC+alpha*
           (listD+alpha listE)))),1],{0,0,0,0,0,0}],
         Join[2 (-2 listA+alpha (-listB+listK+alpha (listL+alpha (listD+listM)))),
           {0,0,0,0,0}]-Join[{0},4 listF+alpha (3 listG+alpha*
           (2 listH+alpha listI)),{0,0,0,0}],
         Join[{0},2 alpha (listB+2 listK+alpha (listC+listL)),{0,0,0,0}]-
           Join[{0,0},6 listF+alpha (3 listG+alpha listH),{0,0,0}],
         Join[{0,0},2 (2 listA+alpha (listB+listK)),{0,0,0}]-
           Join[{0,0,0},4 listF+alpha listG,{0,0}],
         Join[{0,0,0},2 listA,{0,0}]-Join[{0,0,0,0},listF,{0}],
         Join[{0},2 listA+alpha (2 listB+listK+alpha*
           (2 listC+2 alpha listD+listL+alpha listM)),{0,0,0,0}],
         Join[{0,0},6 listA+alpha (4 listB+2 alpha listC+2 listK+alpha listL),
           {0,0,0}],
         Join[{0,0,0},6 listA+alpha (2 listB+listK),{0,0}],
         N0=Join[Drop[(listN+alpha (listO+alpha (listP+alpha (listQ+alpha*
           (listR+alpha (listS+alpha listT))))))/alpha,1],{0,0,0,0,0,0}],
         O0=Join[6 listN/alpha+5 listO+4 alpha listP+3 alpha^2*listQ+
           2 alpha^3*listR+alpha^4*listS,{0,0,0,0,0}]-
           Join[Drop[listF+alpha (listG+alpha (listH+alpha (listI+alpha listJ))),1],
           {0,0,0,0,0,0}],
         Join[Drop[2 listA+alpha (2 listB+listK+alpha (2 listC+2 alpha listD+
           listL+alpha listM)),1],{0,0,0,0,0,0}]-
           Join[4 listF+alpha (3 listG+alpha (2 listH+alpha listI)),{0,0,0,0,0}]+
           Join[{0},15 listN/alpha+10 listO+6 alpha listP+3 alpha^2*listQ+
           alpha^3*listR,{0,0,0,0}],
         Join[6 listA+alpha (4 listB+2 alpha listC+2 listK+alpha listL),
           {0,0,0,0,0}]-Join[{0},6 listF+alpha (3 listG+alpha listH),{0,0,0,0}]+
           Join[{0,0},20 listN/alpha+10 listO+4 alpha listP+alpha^2*listQ,{0,0,0}],
         Join[{0},6 listA+alpha (2 listB+listK),{0,0,0,0}]-
           Join[{0,0},4 listF+alpha listG,{0,0,0}]+
           Join[{0,0,0},15 listN/alpha+5 listO+alpha listP,{0,0}],
         Join[{0,0},2 listA,{0,0,0}]-Join[{0,0,0},listF,{0,0}]+
           Join[{0,0,0,0},6 listN/alpha+listO,{0}],
         Join[{0,0,0,0,0},listN/alpha]},{n,nMax}],
         -1*N0[[1]]/O0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[expTerm,exp2Term,exp3Term,listA,listB,listC,listD,listE,listF,listG,
      listH,listI,listJ,listK,listL,listM,listN,listO,listP,listQ,listR,listS,
      listT,N0,O0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                  DegeneratePainleveD7[z,a,{v,w}]                   *)
(**********************************************************************)

DegeneratePainleveD7[z_,a_,{v_,w_}]:=
  painleveD7Quad[Sqrt[z],a,{v,2 w}];

DegeneratePainleveD7Alternative[z_,a_,{v_,w_}]:=
  Sqrt[z]*DegeneratePainleveD7[Sqrt[z],a,{v,2 w-v}];

painleveD7Quad[z_,a_,{v_,w_}]:=
  v+w*(z-1)+((16*v-16*a*v-16*v^3-v*w+w^2-16)/(2*v))/
  continuFracPD7[(z-1),a,{v,w}]*(z-1)^2/;
  (Precision[z]<Infinity && N[v]=!=0. && 
   N[16*v-16*a*v-16*v^3-v*w+w^2-16]=!=0.)

continuFracPD7[z_,a_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListPD7[a,{v,w}]];

alphaListPD7[a_,{v_,w_}]:=
  alphaListPD7[a,{v,w}]=
    Module[{n,nMax,spA,spV,spW,listA,listB,listC,listD,listE,listF,listG,listH,
        listI,listJ,listK,listL,g0,h0,alpha,alphaList},
      n=1;
      nMax=2000;
      spA=SetPrecision[a,6500];
      spV=SetPrecision[v,6500];
      spW=SetPrecision[w,6500];
      listA={0,0,spV,spV+spW,spW,0,0,0};
      listB={0,0,0,0,1,1,0,0};
      listC={0,0,0,0,0,0,0,0};
      listD={0,4*spV,5*spV+2*spW,3*spW,0,0,0,0};
      listE={0,0,0,0,1,0,0,0};
      listF={0,0,0,0,0,0,0,0};
      listG={16-16*spV+16*spA*spV+16*spV^3+spV*spW-spW^2,
        16*(3-spV+spA*spV+spV^3-spW+spA*spW+3*spV^2*spW),
        16*(3-spW+spA*spW+3*spV^2*spW+3*spV*spW^2),
        16*(1+3*spV*spW^2+spW^3),16*spW^3,0,0,0};
      listH={2*spV,2*(2*spV-spW),-16+16*spA+48*spV^2+spW,
        16*(-1+spA+3*spV^2+6*spV*spW),48*spW*(2*spV+spW),48*spW^2,0,0};
      listI={0,0,-2,0,48*spV,48*(spV+spW),48*spW,0};
      listJ={0,0,0,0,0,0,16,16};
      listK={0,0,0,0,0,0,0,0};
      listL={0,0,0,0,-1,-1,0,0};
      alpha=(16*spV-16*spA*spV-16*spV^3-spV*spW+spW^2-16)/(2*spV);
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
       alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-listB*alpha-listC*alpha^2,{0,0,0}],
         Join[{0},-2*listA-listB*alpha,{0,0}],
         Join[{0,0},-listA,{0}],
         Join[-listD-alpha*listE-alpha^2*listF,{0,0,0}]+
           Join[Drop[-2*listA-2*alpha*listB-2*alpha^2*listC,1],{0,0,0,0}],
         Join[2*alpha*listB+2*alpha*listL,{0,0,0}]+
           Join[{0},-2*listD-alpha*listE,{0,0}],
         Join[{0},2*listA,{0,0}]+Join[{0,0},-listD,{0}],
         g0=Join[Drop[listH+listG/alpha+listI*alpha+listJ*alpha^2+listK*alpha^3,1],
           {0,0,0,0}],
         h0=Join[4*listG/alpha+3*listH+2*alpha*listI+alpha^2*listJ,{0,0,0}]+
           Join[Drop[-listD-alpha*listE-alpha^2*listF,1],{0,0,0,0}],
         Join[-2*listD-alpha*listE,{0,0,0}]+
           Join[{0},6*listG/alpha+3*listH+alpha*listI,{0,0}]+
           Join[Drop[2*listA+2*alpha*listB+alpha*listL,1],{0,0,0,0}],
         Join[2*listA,{0,0,0}]+Join[{0},-listD,{0,0}]+
           Join[{0,0},4*listG/alpha+listH,{0}],
         Join[{0,0,0},listG/alpha],
         Join[{0},2*listA+2*listB*alpha+listL*alpha,{0,0}]},{n,nMax}],
         -1*g0[[1]]/h0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,
          listL,g0,h0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                   DegeneratePainleveD8[z,{v,w}]                    *)
(**********************************************************************)

DegeneratePainleveD8[z_,{v_,w_}]:=
  painleveD8Quad[Sqrt[z],{v,2 w}];

DegeneratePainleveD8Alternative[z_,{v_,w_}]:=
  Sqrt[z]*DegeneratePainleveD8[Sqrt[z],{v,2 w-v}];

painleveD8Quad[z_,{v_,w_}]:=
  v+w*(z-1)+((16*v-16*v^3-v*w+w^2)/(2*v))/
  continuFracPD8[(z-1),{v,w}]*(z-1)^2/;
  (Precision[z]<Infinity && N[16*v-16*v^3-v*w+w^2]=!=0. && N[v]=!=0.)

continuFracPD8[z_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListPD8[{v,w}]];

alphaListPD8[{v_,w_}]:=
  alphaListPD8[{v,w}]=
    Module[{n,nMax,spV,spW,listA,listB,listC,listD,listE,listF,listG,
        listH,listI,listJ,listK,listL,g0,h0,alpha,alphaList},
      n=1;
      nMax=2000;
      spV=SetPrecision[v,6500];
      spW=SetPrecision[w,6500];
      listA={0,0,spV,spV+spW,spW,0,0,0};
      listB={0,0,0,0,1,1,0,0};
      listC={0,0,0,0,0,0,0,0};
      listD={0,4*spV,5*spV+2*spW,3*spW,0,0,0,0};
      listE={0,0,0,0,1,0,0,0};
      listF={0,0,0,0,0,0,0,0};
      listG={-16*spV+16*spV^3+spV*spW-spW^2,16*(-spV+spV^3-spW+3*spV^2*spW),
        16*spW*(-1+3*spV^2+3*spV*spW),16*spW^2*(3*spV+spW),16*spW^3,0,0,0};
      listH={2*spV,2*(2*spV-spW),-16+48*spV^2+spW,16*(-1+3*spV^2+6*spV*spW),
        48*spW*(2*spV+spW),48*spW^2,0,0};
      listI={0,0,-2,0,48*spV,48*(spV+spW),48*spW,0};
      listJ={0,0,0,0,0,0,16,16};
      listK={0,0,0,0,0,0,0,0};
      listL={0,0,0,0,-1,-1,0,0};
      alpha=(16*spV-16*spV^3-spV*spW+spW^2)/(2*spV);
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,
       listL,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-listB*alpha-listC*alpha^2,{0,0,0}],
         Join[{0},-2*listA-listB*alpha,{0,0}],
         Join[{0,0},-listA,{0}],
         Join[-listD-alpha*listE-alpha^2*listF,{0,0,0}]+
           Join[Drop[-2*listA-2*alpha*listB-2*alpha^2*listC,1],{0,0,0,0}],
         Join[2*alpha*listB+2*alpha*listL,{0,0,0}]+
           Join[{0},-2*listD-alpha*listE,{0,0}],
         Join[{0},2*listA,{0,0}]+Join[{0,0},-listD,{0}],
         g0=Join[Drop[listH+listG/alpha+listI*alpha+listJ*alpha^2+listK*alpha^3,1],
           {0,0,0,0}],
         h0=Join[4*listG/alpha+3*listH+2*alpha*listI+alpha^2*listJ,{0,0,0}]+
           Join[Drop[-listD-alpha*listE-alpha^2*listF,1],{0,0,0,0}],
         Join[-2*listD-alpha*listE,{0,0,0}]+
           Join[{0},6*listG/alpha+3*listH+alpha*listI,{0,0}]+
           Join[Drop[2*listA+2*alpha*listB+alpha*listL,1],{0,0,0,0}],
         Join[2*listA,{0,0,0}]+Join[{0},-listD,{0,0}]+
           Join[{0,0},4*listG/alpha+listH,{0}],
         Join[{0,0,0},listG/alpha],
         Join[{0},2*listA+2*listB*alpha+listL*alpha,{0,0}]},{n,nMax}],
         -1*g0[[1]]/h0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
          listK,listL,g0,h0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                      QuasiPainleveE1[z,{v,w}]                      *)
(**********************************************************************)

QuasiPainleveE1[z_,{v_,w_}]:=
  v+w*z+(5/9*v^4)/continuFracE1[z,{v,w}]*z^2/;
  (Precision[z]<Infinity && N[v]=!=0.)

continuFracE1[z_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListE1[{v,w}]];

alphaListE1[{v_,w_}]:=
  alphaListE1[{v,w}]=
    Module[{n,nMax,spV,spW,listA,listB,listC,listD,listE,listF,
     listG,listH,listI,listJ,listK,listL,g0,h0,alpha,alphaList},
      n=1;
      nMax=3500;
      spV=SetPrecision[v,9000];
      spW=SetPrecision[w,9000];
      listA={0,0,1,0,0,0,0,0,0};
      listB={0,0,0,0,0,0,0,0,0};
      listC={0,0,0,0,0,0,0,0,0};
      listD={0,4,0,0,0,0,0,0,0};
      listE={0,0,0,0,0,0,0,0,0};
      listF={0,0,0,0,0,0,0,0,0};
      listG={-10/9*spV^4,-1-40/9*spV^3*spW,-20/3*spV^2*spW^2,
        -40/9*spV*spW^3,-10/9*spW^4,0,0,0,0};
      listH={2,0,-40/9*spV^3,-40/3*spV^2*spW,-40/3*spV*spW^2,
        -40/9*spW^3,0,0,0};
      listI={0,0,0,0,-20/3*spV^2,-40/3*spV*spW,-20/3*spW^2,0,0};
      listJ={0,0,0,0,0,0,-40/9*spV,-40/9*spW,0};
      listK={0,0,0,0,0,0,0,0,-10/9};
      listL={0,0,0,0,0,0,0,0,0};
      alpha=5/9*spV^4;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
       listK,listL,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-listB*alpha-listC*alpha^2,{0,0,0}],
         Join[{0},-2*listA-listB*alpha,{0,0}],
         Join[{0,0},-listA,{0}],
         Join[-listD-alpha*listE-alpha^2*listF,{0,0,0}]+
           Join[Drop[-2*listA-2*alpha*listB-2*alpha^2*listC,1],{0,0,0,0}],
         Join[2*alpha*listB+2*alpha*listL,{0,0,0}]+
           Join[{0},-2*listD-alpha*listE,{0,0}],
         Join[{0},2*listA,{0,0}]+Join[{0,0},-listD,{0}],
         g0=Join[Drop[listH+listG/alpha+listI*alpha+listJ*alpha^2+listK*alpha^3,1],
           {0,0,0,0}],
         h0=Join[4*listG/alpha+3*listH+2*alpha*listI+alpha^2*listJ,{0,0,0}]+
           Join[Drop[-listD-alpha*listE-alpha^2*listF,1],{0,0,0,0}],
         Join[-2*listD-alpha*listE,{0,0,0}]+
           Join[{0},6*listG/alpha+3*listH+alpha*listI,{0,0}]+
           Join[Drop[2*listA+2*alpha*listB+alpha*listL,1],{0,0,0,0}],
         Join[2*listA,{0,0,0}]+Join[{0},-listD,{0,0}]+
           Join[{0,0},4*listG/alpha+listH,{0}],
         Join[{0,0,0},listG/alpha],
         Join[{0},2*listA+2*listB*alpha+listL*alpha,{0,0}]},{n,nMax}],
         -1*g0[[1]]/h0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,
          listK,listL,g0,h0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                     QuasiPainleveE2[z,a,{v,w}]                     *)
(**********************************************************************)

QuasiPainleveE2[z_,a_,{v_,w_}]:=
  v+w*z+((4*a+3*v^5)/8)/continuFracE2[z,a,{v,w}]*z^2/;
  (Precision[z]<Infinity && N[4*a+3*v^5]=!=0.)

continuFracE2[z_,a_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListE2[a,{v,w}]];

alphaListE2[a_,{v_,w_}]:=
  alphaListE2[a,{v,w}]=
    Module[{n,nMax,spA,spV,spW,listA,listB,listC,listD,listE,listF,listG,listH,
        listI,listJ,listK,listL,listM,listN,listO,listP,K0,L0,alpha,alphaList},
      n=1;
      nMax=2500;
      spA=SetPrecision[a,8000];
      spV=SetPrecision[v,8000];
      spW=SetPrecision[w,8000];
      listA={0,0,1,0,0,0,0,0,0,0,0};
      listB={0,0,0,0,0,0,0,0,0,0,0};
      listC={0,0,0,0,0,0,0,0,0,0,0};
      listD={0,0,0,0,0,0,0,0,0,0,0};
      listE={0,4,0,0,0,0,0,0,0,0,0};
      listF={0,0,0,0,0,0,0,0,0,0,0};
      listG={0,0,0,0,0,0,0,0,0,0,0};
      listH={0,0,0,0,0,0,0,0,0,0,0};
      listI={0,0,0,0,0,0,0,0,0,0,0};
      listJ={0,0,0,0,0,0,0,0,0,0,0};
      listK={(-4*spA-3*spV^5)/4,-spV^2*(4+15*spV^2*spW)/4,
        -spV*spW*(4+15*spV^2*spW)/2,-spW^2*(2+15*spV^2*spW)/2,-15/4*spV*spW^4,
        -3/4*spW^5,0,0,0,0,0};
      listL={2,0,-15/4*spV^4,-spV*(2+15*spV^2*spW),-spW*(4+45*spV^2*spW)/2,
        -15*spV*spW^3,-15/4*spW^4,0,0,0,0};
      listM={0,0,0,0,-15/2*spV^3,(-2-45*spV^2*spW)/2,-45/2*spV*spW^2,
        -15/2*spW^3,0,0,0};
      listN={0,0,0,0,0,0,-15/2*spV^2,-15*spV*spW,-15/2*spW^2,0,0};
      listO={0,0,0,0,0,0,0,0,-15/4*spV,-15/4*spW,0};
      listP={0,0,0,0,0,0,0,0,0,0,-3/4};
      alpha=(4*spA+3*spV^5)/8;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,listL,
       listM,listN,listO,listP,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB-alpha^2*listC-alpha^3*listD,{0,0,0,0}],
         Join[{0},-3*listA-2*alpha*listB-alpha^2*listC,{0,0,0}],
         Join[{0,0},-3*listA-alpha*listB,{0,0}],
         Join[{0,0,0},-listA,{0}],
         Join[-listE-alpha*listF-alpha^2*listG-alpha^3*listH,{0,0,0,0}]-
           Join[Drop[2*listA+2*alpha*listB+2*alpha^2*listC+2*alpha^3*listD,1],
             {0,0,0,0,0}],
         Join[-2*listA+2*alpha^2*listC+2*alpha*listI+2*alpha^2*listJ,{0,0,0,0}]-
           Join[{0},3*listE+2*alpha*listF+alpha^2*listG,{0,0,0}],
         Join[{0},2*listA+2*alpha*listB+2*alpha*listI,{0,0,0}]-
           Join[{0,0},3*listE+alpha*listF,{0,0}],
         Join[{0,0},2*listA,{0,0}]-Join[{0,0,0},listE,{0}],
         Join[{0},2*listA+2*alpha*listB+2*alpha^2*listC+alpha*listI+alpha^2*listJ,
           {0,0,0}],
         Join[{0,0},4*listA+2*alpha*listB+alpha*listI,{0,0}],
         K0=Join[Drop[listK/alpha+listL+alpha*listM+alpha^2*listN+alpha^3*listO+
           alpha^4*listP,1],{0,0,0,0,0}],
         L0=Join[5*listK/alpha+4*listL+3*alpha*listM+2*alpha^2*listN+alpha^3*listO,
           {0,0,0,0}]-
           Join[Drop[listE+alpha*listF+alpha^2*listG+alpha^3*listH,1],{0,0,0,0,0}],
         Join[{0},10*listK/alpha+6*listL+3*alpha*listM+alpha^2*listN,{0,0,0}]-
           Join[3*listE+2*alpha*listF+alpha^2*listG,{0,0,0,0}]+
           Join[Drop[2*listA+2*alpha*listB+2*alpha^2*listC+alpha*listI+
             alpha^2*listJ,1],{0,0,0,0,0}],
         Join[4*listA+2*alpha*listB+alpha*listI,{0,0,0,0}]-
           Join[{0},3*listE+alpha*listF,{0,0,0}]+
           Join[{0,0},10*listK/alpha+4*listL+alpha*listM,{0,0}],
         Join[{0},2*listA,{0,0,0}]-Join[{0,0},listE,{0,0}]+
           Join[{0,0,0},5 listK/alpha+listL,{0}],
         Join[{0,0,0,0},listK/alpha]},{n,nMax}],
         -1*K0[[1]]/L0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,listI,listJ,listK,
          listL,listM,listN,listO,listP,K0,L0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                      QuasiPainleveF1[z,{v,w}]                      *)
(**********************************************************************)

QuasiPainleveF1[z_,{v_,w_}]:=
  v+w*z+v^3/continuFracF1[z,{v,w}]*z^2/;
  (Precision[z]<Infinity && N[v]=!=0.)

continuFracF1[z_,{v_,w_}]:=
  Fold[(1+z*#2/#1)&,1,alphaListF1[{v,w}]];

alphaListF1[{v_,w_}]:=
  alphaListF1[{v,w}]=
    Module[{n,nMax,spV,spW,listA,listB,listC,listD,listE,listF,
     listG,listH,e0,f0,alpha,alphaList},
      n=1;
      nMax=3500;
      spV=SetPrecision[v,7000];
      spW=SetPrecision[w,7000];
      listA={0,0,1,0,0,0,0};
      listB={0,0,0,0,0,0,0};
      listC={0,4,0,0,0,0,0};
      listD={0,0,0,0,0,0,0};
      listE={-2*spV^3,-1-6*spV^2*spW,-6*spV*spW^2,-2*spW^3,0,0,0};
      listF={2,0,-6*spV^2,-12*spV*spW,-6*spW^2,0,0};
      listG={0,0,0,0,-6*spV,-6*spW,0};
      listH={0,0,0,0,0,0,-2};
      alpha=spV^3;
      alphaList={};
    While[n<=nMax,
      {listA,listB,listC,listD,listE,listF,listG,listH,alpha,alphaList}=
      Flatten[{myDrop[
        {Join[-listA-alpha*listB,{0,0}],
         Join[{0},-listA,{0}],
         Join[Drop[-2*listA-2*alpha*listB,1],{0,0,0}]+
           Join[-listC-alpha*listD,{0,0}],
         Join[2*listA,{0,0}]+Join[{0},-listC,{0}],
         e0=Join[Drop[listE/alpha+listF+alpha*listG+alpha^2*listH,1],{0,0,0}],
         f0=Join[Drop[-listC-alpha*listD,1],{0,0,0}]+
           Join[3*listE/alpha+2*listF+alpha*listG,{0,0}],
         Join[Drop[2*listA,1],{0,0,0}]+Join[-listC,{0,0}]+
           Join[{0},3*listE/alpha+listF,{0}],
         Join[{0,0},listE/alpha]},{n,nMax}],
         -1*e0[[1]]/f0[[1]],
         {Join[alphaList,{N[alpha,100]}]}},1];n++];
    Clear[listA,listB,listC,listD,listE,listF,listG,listH,e0,f0,alpha];
    Reverse[Delete[alphaList,1]]];



(**********************************************************************)
(*                    YablonskiiVorobevQ[ord,n,z]                     *)
(**********************************************************************)

YablonskiiVorobevQ[n_Integer,z_]:=YablonskiiVorobevQ[1,n,z];

YablonskiiVorobevQ[ord_Integer,n_Integer,z_]:=
  Product[(2 k+1)^(n-k),{k,1,n}]*
  Det[Table[Take[coefListYVQ[ord,n,z],{2 n-2 k+1,3 n-2 k}],{k,1,n}]]/;
  (ord>0 && n>0)

coefListYVQ[ord_Integer,n_Integer,z_]:=
  Module[{t},
  PadLeft[
    Apply[Plus,Table[
      PadRight[
        CoefficientList[(z*t-4^ord/(2*ord+1)*t^(2*ord+1))^i,t]/(i!),
        2 n],
      {i,0,2 n-1}]],
    3 n-2]];



(**********************************************************************)
(*                      ClassicalPainleveP2[n,z]                      *)
(**********************************************************************)

ClassicalPainleveP2[n_,{z_,c_}]:=
  ClassicalPainleveP2[n,z]/;
  (N[Abs[n-Round[n]]]===0. && Precision[z]<Infinity)

ClassicalPainleveP2[n_,z_]:=
  Module[{val},
    val=If[n>=0,
      compileCPP2Int[N[n],z+0.0 I],-compileCPP2Int[N[-n],z+0.0 I]];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0. && Precision[z]<Infinity)

ClassicalPainleveP2[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,
      compileCPP2Frac[N[n],z+0.0 I,c+0.0 I],
      -compileCPP2Frac[N[-n],z+0.0 I,c+0.0 I]];
    If[Abs[Im[z]]>0 || Abs[Im[c]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]<6 && 
   Not[MemberQ[{Infinity,+Infinity,-Infinity},c]] && 
   Precision[z]<Infinity)

ClassicalPainleveP2[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,
      compileCPP2FracInf[N[n],z+0.0 I],
      -compileCPP2FracInf[N[-n],z+0.0 I]];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]<6 && 
   MemberQ[{Infinity,+Infinity,-Infinity},c] && 
   Precision[z]<Infinity)

ClassicalPainleveP2[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,precCPP2Frac[n,z,c],-precCPP2Frac[-n,z,c]];
    If[Abs[Im[z]]>0 || Abs[Im[c]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]>6 && 
   Not[MemberQ[{Infinity,+Infinity,-Infinity},c]] && 
   Precision[z]<Infinity)

ClassicalPainleveP2[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,precCPP2FracInf[n,z],-precCPP2FracInf[-n,z]];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]>6 && 
   MemberQ[{Infinity,+Infinity,-Infinity},c] && 
   Precision[z]<Infinity)

compileCPP2Int=Compile[{{n,_Real},{z,_Complex}},
  Module[{k=0,den,w0,w1,w0New,w1New},
    w0=0.+0 I;w1=0.+0 I;
    w0New=0.+0 I;w1New=0.+0 I;
    While[k<n,
      den=z+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    w0]];

compileCPP2Frac=Compile[{{n,_Real},{z,_Complex},{c,_Complex}},
  Module[{k=0.5,den,w0,w1,w0New,w1New},
    w0=2^(-1/3)*(AiryAiPrime[-2^(-1/3)*z]+c*AiryBiPrime[-2^(-1/3)*z])/
      (AiryAi[-2^(-1/3)*z]+c*AiryBi[-2^(-1/3)*z]);
    w1=z/2+w0^2;
    w0New=0.+0 I;w1New=0.+0 I;
    While[k<n,
      den=z+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    w0]];

compileCPP2FracInf=Compile[{{n,_Real},{z,_Complex}},
  Module[{k=0.5,den,w0,w1,w0New,w1New},
    w0=2^(-1/3)*AiryBiPrime[-2^(-1/3)*z]/AiryBi[-2^(-1/3)*z];
    w1=z/2+w0^2;
    w0New=0.+0 I;w1New=0.+0 I;
    While[k<n,
      den=z+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    w0]];

precCPP2Frac[n_,z_,c_]:=
  Module[{k=1/2,prec=22,pz,pc,den,w0,w1,w0New,w1New},
    Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];pc=SetPrecision[c,prec];
    w0=2^(-1/3)*(AiryAiPrime[-2^(-1/3)*pz]+pc*AiryBiPrime[-2^(-1/3)*pz])/
      (AiryAi[-2^(-1/3)*pz]+pc*AiryBi[-2^(-1/3)*pz]);
    w1=pz/2+w0^2;
    w0New=0;w1New=0;
    While[k<n,
      den=pz+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    N[w0]]];

precCPP2FracInf[n_,z_]:=
  Module[{k=1/2,prec=22,pz,den,w0,w1,w0New,w1New},
    Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];
    w0=2^(-1/3)*AiryBiPrime[-2^(-1/3)*pz]/AiryBi[-2^(-1/3)*pz];
    w1=pz/2+w0^2;
    w0New=0;w1New=0;
    While[k<n,
      den=pz+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    N[w0]]];



(**********************************************************************)
(*                   ClassicalPainleveP2Prime[n,z]                    *)
(**********************************************************************)

ClassicalPainleveP2Prime[n_,{z_,c_}]:=
  ClassicalPainleveP2Prime[n,z]/;
  (N[Abs[n-Round[n]]]===0. && Precision[z]<Infinity)

ClassicalPainleveP2Prime[n_,z_]:=
  Module[{val},
    val=If[n>=0,
      compileCPP2IntPrime[N[n],z+0.0 I],
      -compileCPP2IntPrime[N[-n],z+0.0 I]];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0. && Precision[z]<Infinity)

ClassicalPainleveP2Prime[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,
      compileCPP2FracPrime[N[n],z+0.0 I,c+0.0 I],
      -compileCPP2FracPrime[N[-n],z+0.0 I,c+0.0 I]];
    If[Abs[Im[z]]>0 || Abs[Im[c]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]<6 && 
   Not[MemberQ[{Infinity,+Infinity,-Infinity},c]] && 
   Precision[z]<Infinity)

ClassicalPainleveP2Prime[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,
      compileCPP2FracInfPrime[N[n],z+0.0 I],
      -compileCPP2FracInfPrime[N[-n],z+0.0 I]];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]<6 && 
   MemberQ[{Infinity,+Infinity,-Infinity},c] && 
   Precision[z]<Infinity)

ClassicalPainleveP2Prime[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,precCPP2FracPrime[n,z,c],-precCPP2FracPrime[-n,z,c]];
    If[Abs[Im[z]]>0 || Abs[Im[c]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]>6 && 
   Not[MemberQ[{Infinity,+Infinity,-Infinity},c]] && 
   Precision[z]<Infinity)

ClassicalPainleveP2Prime[n_,{z_,c_}]:=
  Module[{val},
    val=If[n>-1,precCPP2FracInfPrime[n,z],-precCPP2FracInfPrime[-n,z]];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (N[Abs[n-Round[n]]]===0.5 && Abs[n]>6 && 
   MemberQ[{Infinity,+Infinity,-Infinity},c] && 
   Precision[z]<Infinity)

compileCPP2IntPrime=Compile[{{n,_Real},{z,_Complex}},
  Module[{k=0,den,w0,w1,w0New,w1New},
    w0=0.+0 I;w1=0.+0 I;
    w0New=0.+0 I;w1New=0.+0 I;
    While[k<n,
      den=z+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    w1]];

compileCPP2FracPrime=Compile[{{n,_Real},{z,_Complex},{c,_Complex}},
  Module[{k=0.5,den,w0,w1,w0New,w1New},
    w0=2^(-1/3)*(AiryAiPrime[-2^(-1/3)*z]+c*AiryBiPrime[-2^(-1/3)*z])/
      (AiryAi[-2^(-1/3)*z]+c*AiryBi[-2^(-1/3)*z]);
    w1=z/2+w0^2;
    w0New=0.+0 I;w1New=0.+0 I;
    While[k<n,
      den=z+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    w1]];

compileCPP2FracInfPrime=Compile[{{n,_Real},{z,_Complex}},
  Module[{k=0.5,den,w0,w1,w0New,w1New},
    w0=2^(-1/3)*AiryBiPrime[-2^(-1/3)*z]/AiryBi[-2^(-1/3)*z];
    w1=z/2+w0^2;
    w0New=0.+0 I;w1New=0.+0 I;
    While[k<n,
      den=z+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    w1]];

precCPP2FracPrime[n_,z_,c_]:=
  Module[{k=1/2,prec=22,pz,pc,den,w0,w1,w0New,w1New},
    Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];pc=SetPrecision[c,prec];
    w0=2^(-1/3)*(AiryAiPrime[-2^(-1/3)*pz]+pc*AiryBiPrime[-2^(-1/3)*pz])/
      (AiryAi[-2^(-1/3)*pz]+pc*AiryBi[-2^(-1/3)*pz]);
    w1=pz/2+w0^2;
    w0New=0;w1New=0;
    While[k<n,
      den=pz+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    N[w1]]];

precCPP2FracInfPrime[n_,z_]:=
  Module[{k=1/2,prec=22,pz,den,w0,w1,w0New,w1New},
    Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];
    w0=2^(-1/3)*AiryBiPrime[-2^(-1/3)*pz]/AiryBi[-2^(-1/3)*pz];
    w1=pz/2+w0^2;
    w0New=0;w1New=0;
    While[k<n,
      den=pz+2 w0^2+2 w1;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w0=w0New;w1=w1New;
      k++];
    N[w1]]];



(**********************************************************************)
(*                   ClassicalOrder4PainleveP2[n,z]                   *)
(**********************************************************************)

ClassicalOrder4PainleveP2[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO4PP2[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO4PP2[n_,z_]:=
  Module[{k=0,prec=16,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;
    While[k<n,
      den=pz-6 w0^4-12 w0^2*w1-2 w1^2+4 w0*w2+2 w3;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2+2 (1+2 k) (w1-2 w0^2)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3-
        4 (1+2 k)^2*(2 w1-7 w0^2)/den^2-2 (1+2 k) (6 w0 w1-4 w0^3-w2)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;
      k++];
    N[w0]]];

ClassicalOrder4PainleveP2Prime[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO4PP2Prime[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO4PP2Prime[n_,z_]:=
  Module[{k=0,prec=16,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;
    While[k<n,
      den=pz-6 w0^4-12 w0^2*w1-2 w1^2+4 w0*w2+2 w3;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2+2 (1+2 k) (w1-2 w0^2)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3-
        4 (1+2 k)^2*(2 w1-7 w0^2)/den^2-2 (1+2 k) (6 w0 w1-4 w0^3-w2)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;
      k++];
    N[w1]]];

ClassicalOrder4PainleveP2Prime2[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO4PP2Prime2[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO4PP2Prime2[n_,z_]:=
  Module[{k=0,prec=16,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;
    While[k<n,
      den=pz-6 w0^4-12 w0^2*w1-2 w1^2+4 w0*w2+2 w3;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2+2 (1+2 k) (w1-2 w0^2)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3-
        4 (1+2 k)^2*(2 w1-7 w0^2)/den^2-2 (1+2 k) (6 w0 w1-4 w0^3-w2)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;
      k++];
    N[w2]]];

ClassicalOrder4PainleveP2Prime3[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO4PP2Prime3[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO4PP2Prime3[n_,z_]:=
  Module[{k=0,prec=16,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;
    While[k<n,
      den=pz-6 w0^4-12 w0^2*w1-2 w1^2+4 w0*w2+2 w3;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2+2 (1+2 k) (w1-2 w0^2)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3-
        4 (1+2 k)^2*(2 w1-7 w0^2)/den^2-2 (1+2 k) (6 w0 w1-4 w0^3-w2)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;
      k++];
    N[w3]]];



(**********************************************************************)
(*                   ClassicalOrder6PainleveP2[n,z]                   *)
(**********************************************************************)

ClassicalOrder6PainleveP2[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO6PP2[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO6PP2[n_,z_]:=
  Module[{k=0,prec=20,pz,den,w0,w1,w2,w3,w4,w5,w0New,w1New,w2New,w3New,w4New,w5New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;w4=0;w5=0;
    While[k<n,
      den=pz+20 w0^6+60 w0^4*w1-20 w0^2*w1^2-20 w1^3-40 w0^3*w2-80 w0 w1 w2+
        2 w2^2-20 w0^2*w3-4 w1 w3+4 w0 w4+2 w5;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2-2 (1+2 k) (2 w0^2-w1)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3+
        4 (1+2 k)^2*(7 w0^2-2 w1)/den^2+2 (1+2 k) (4 w0^3-6 w0 w1+w2)/den;
      w4New=-w4-24 (1+2 k)^5/den^5-120 (1+2 k)^4*w0/den^4-
        40 (1+2 k)^3*(5 w0^2-w1)/den^3-10 (1+2 k)^2*(12 w0^3-10 w0 w1+w2)/den^2-
        2 (1+2 k) (8 w0^4-24 w0^2*w1+6 w1^2+8 w0 w2-w3)/den;
      w5New=-w5+120 (1+2 k)^6/den^6+720 (1+2 k)^5*w0/den^5+
        120 (1+2 k)^4*(13 w0^2-2 w1)/den^4+60 (1+2 k)^3*(24 w0^3-14 w0 w1+w2)/den^3+
        4 (1+2 k)^2*(124 w0^4-202 w0^2*w1+28 w1^2+39 w0 w2-3 w3)/den^2+
        2 (1+2 k) (16 w0^5-80 w0^3*w1+60 w0 w1^2+40 w0^2*w2-20 w1 w2-10 w0 w3+w4)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;w4=w4New;w5=w5New;
      k++];
    N[w0]]];

ClassicalOrder6PainleveP2Prime[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO6PP2Prime[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO6PP2Prime[n_,z_]:=
  Module[{k=0,prec=20,pz,den,w0,w1,w2,w3,w4,w5,w0New,w1New,w2New,w3New,w4New,w5New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;w4=0;w5=0;
    While[k<n,
      den=pz+20 w0^6+60 w0^4*w1-20 w0^2*w1^2-20 w1^3-40 w0^3*w2-80 w0 w1 w2+
        2 w2^2-20 w0^2*w3-4 w1 w3+4 w0 w4+2 w5;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2-2 (1+2 k) (2 w0^2-w1)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3+
        4 (1+2 k)^2*(7 w0^2-2 w1)/den^2+2 (1+2 k) (4 w0^3-6 w0 w1+w2)/den;
      w4New=-w4-24 (1+2 k)^5/den^5-120 (1+2 k)^4*w0/den^4-
        40 (1+2 k)^3*(5 w0^2-w1)/den^3-10 (1+2 k)^2*(12 w0^3-10 w0 w1+w2)/den^2-
        2 (1+2 k) (8 w0^4-24 w0^2*w1+6 w1^2+8 w0 w2-w3)/den;
      w5New=-w5+120 (1+2 k)^6/den^6+720 (1+2 k)^5*w0/den^5+
        120 (1+2 k)^4*(13 w0^2-2 w1)/den^4+60 (1+2 k)^3*(24 w0^3-14 w0 w1+w2)/den^3+
        4 (1+2 k)^2*(124 w0^4-202 w0^2*w1+28 w1^2+39 w0 w2-3 w3)/den^2+
        2 (1+2 k) (16 w0^5-80 w0^3*w1+60 w0 w1^2+40 w0^2*w2-20 w1 w2-10 w0 w3+w4)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;w4=w4New;w5=w5New;
      k++];
    N[w1]]];

ClassicalOrder6PainleveP2Prime2[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO6PP2Prime2[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO6PP2Prime2[n_,z_]:=
  Module[{k=0,prec=20,pz,den,w0,w1,w2,w3,w4,w5,w0New,w1New,w2New,w3New,w4New,w5New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;w4=0;w5=0;
    While[k<n,
      den=pz+20 w0^6+60 w0^4*w1-20 w0^2*w1^2-20 w1^3-40 w0^3*w2-80 w0 w1 w2+
        2 w2^2-20 w0^2*w3-4 w1 w3+4 w0 w4+2 w5;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2-2 (1+2 k) (2 w0^2-w1)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3+
        4 (1+2 k)^2*(7 w0^2-2 w1)/den^2+2 (1+2 k) (4 w0^3-6 w0 w1+w2)/den;
      w4New=-w4-24 (1+2 k)^5/den^5-120 (1+2 k)^4*w0/den^4-
        40 (1+2 k)^3*(5 w0^2-w1)/den^3-10 (1+2 k)^2*(12 w0^3-10 w0 w1+w2)/den^2-
        2 (1+2 k) (8 w0^4-24 w0^2*w1+6 w1^2+8 w0 w2-w3)/den;
      w5New=-w5+120 (1+2 k)^6/den^6+720 (1+2 k)^5*w0/den^5+
        120 (1+2 k)^4*(13 w0^2-2 w1)/den^4+60 (1+2 k)^3*(24 w0^3-14 w0 w1+w2)/den^3+
        4 (1+2 k)^2*(124 w0^4-202 w0^2*w1+28 w1^2+39 w0 w2-3 w3)/den^2+
        2 (1+2 k) (16 w0^5-80 w0^3*w1+60 w0 w1^2+40 w0^2*w2-20 w1 w2-10 w0 w3+w4)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;w4=w4New;w5=w5New;
      k++];
    N[w2]]];

ClassicalOrder6PainleveP2Prime3[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO6PP2Prime3[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO6PP2Prime3[n_,z_]:=
  Module[{k=0,prec=20,pz,den,w0,w1,w2,w3,w4,w5,w0New,w1New,w2New,w3New,w4New,w5New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;w4=0;w5=0;
    While[k<n,
      den=pz+20 w0^6+60 w0^4*w1-20 w0^2*w1^2-20 w1^3-40 w0^3*w2-80 w0 w1 w2+
        2 w2^2-20 w0^2*w3-4 w1 w3+4 w0 w4+2 w5;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2-2 (1+2 k) (2 w0^2-w1)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3+
        4 (1+2 k)^2*(7 w0^2-2 w1)/den^2+2 (1+2 k) (4 w0^3-6 w0 w1+w2)/den;
      w4New=-w4-24 (1+2 k)^5/den^5-120 (1+2 k)^4*w0/den^4-
        40 (1+2 k)^3*(5 w0^2-w1)/den^3-10 (1+2 k)^2*(12 w0^3-10 w0 w1+w2)/den^2-
        2 (1+2 k) (8 w0^4-24 w0^2*w1+6 w1^2+8 w0 w2-w3)/den;
      w5New=-w5+120 (1+2 k)^6/den^6+720 (1+2 k)^5*w0/den^5+
        120 (1+2 k)^4*(13 w0^2-2 w1)/den^4+60 (1+2 k)^3*(24 w0^3-14 w0 w1+w2)/den^3+
        4 (1+2 k)^2*(124 w0^4-202 w0^2*w1+28 w1^2+39 w0 w2-3 w3)/den^2+
        2 (1+2 k) (16 w0^5-80 w0^3*w1+60 w0 w1^2+40 w0^2*w2-20 w1 w2-10 w0 w3+w4)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;w4=w4New;w5=w5New;
      k++];
    N[w3]]];

ClassicalOrder6PainleveP2Prime4[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO6PP2Prime4[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO6PP2Prime4[n_,z_]:=
  Module[{k=0,prec=20,pz,den,w0,w1,w2,w3,w4,w5,w0New,w1New,w2New,w3New,w4New,w5New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;w4=0;w5=0;
    While[k<n,
      den=pz+20 w0^6+60 w0^4*w1-20 w0^2*w1^2-20 w1^3-40 w0^3*w2-80 w0 w1 w2+
        2 w2^2-20 w0^2*w3-4 w1 w3+4 w0 w4+2 w5;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2-2 (1+2 k) (2 w0^2-w1)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3+
        4 (1+2 k)^2*(7 w0^2-2 w1)/den^2+2 (1+2 k) (4 w0^3-6 w0 w1+w2)/den;
      w4New=-w4-24 (1+2 k)^5/den^5-120 (1+2 k)^4*w0/den^4-
        40 (1+2 k)^3*(5 w0^2-w1)/den^3-10 (1+2 k)^2*(12 w0^3-10 w0 w1+w2)/den^2-
        2 (1+2 k) (8 w0^4-24 w0^2*w1+6 w1^2+8 w0 w2-w3)/den;
      w5New=-w5+120 (1+2 k)^6/den^6+720 (1+2 k)^5*w0/den^5+
        120 (1+2 k)^4*(13 w0^2-2 w1)/den^4+60 (1+2 k)^3*(24 w0^3-14 w0 w1+w2)/den^3+
        4 (1+2 k)^2*(124 w0^4-202 w0^2*w1+28 w1^2+39 w0 w2-3 w3)/den^2+
        2 (1+2 k) (16 w0^5-80 w0^3*w1+60 w0 w1^2+40 w0^2*w2-20 w1 w2-10 w0 w3+w4)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;w4=w4New;w5=w5New;
      k++];
    N[w4]]];

ClassicalOrder6PainleveP2Prime5[n_Integer?NonNegative,z_]:=
  Module[{val},
    val=numCO6PP2Prime5[n,z];
    If[Abs[Im[z]]>0,val,Re[val]]]/;(Precision[z]<Infinity)

numCO6PP2Prime5[n_,z_]:=
  Module[{k=0,prec=20,pz,den,w0,w1,w2,w3,w4,w5,w0New,w1New,w2New,w3New,w4New,w5New},
    Block[{$MinPrecision=prec},
      pz=SetPrecision[z,prec];
      w0=0;w1=0;w2=0;w3=0;w4=0;w5=0;
    While[k<n,
      den=pz+20 w0^6+60 w0^4*w1-20 w0^2*w1^2-20 w1^3-40 w0^3*w2-80 w0 w1 w2+
        2 w2^2-20 w0^2*w3-4 w1 w3+4 w0 w4+2 w5;
      w0New=-w0-(2 k+1)/den;
      w1New=-w1+(1+2 k)^2/den^2+2 (1+2 k) w0/den;
      w2New=-w2-2 (1+2 k)^3/den^3-6 (1+2 k)^2*w0/den^2-2 (1+2 k) (2 w0^2-w1)/den;
      w3New=-w3+6 (1+2 k)^4/den^4+24 (1+2 k)^3*w0/den^3+
        4 (1+2 k)^2*(7 w0^2-2 w1)/den^2+2 (1+2 k) (4 w0^3-6 w0 w1+w2)/den;
      w4New=-w4-24 (1+2 k)^5/den^5-120 (1+2 k)^4*w0/den^4-
        40 (1+2 k)^3*(5 w0^2-w1)/den^3-10 (1+2 k)^2*(12 w0^3-10 w0 w1+w2)/den^2-
        2 (1+2 k) (8 w0^4-24 w0^2*w1+6 w1^2+8 w0 w2-w3)/den;
      w5New=-w5+120 (1+2 k)^6/den^6+720 (1+2 k)^5*w0/den^5+
        120 (1+2 k)^4*(13 w0^2-2 w1)/den^4+60 (1+2 k)^3*(24 w0^3-14 w0 w1+w2)/den^3+
        4 (1+2 k)^2*(124 w0^4-202 w0^2*w1+28 w1^2+39 w0 w2-3 w3)/den^2+
        2 (1+2 k) (16 w0^5-80 w0^3*w1+60 w0 w1^2+40 w0^2*w2-20 w1 w2-10 w0 w3+w4)/den;
      w0=w0New;w1=w1New;w2=w2New;w3=w3New;w4=w4New;w5=w5New;
      k++];
    N[w5]]];



(**********************************************************************)
(*               ClassicalOrder4KaupKupershmidt[a,b,z]                *)
(**********************************************************************)

ClassicalOrder4KaupKupershmidt[a_,b_Integer,z_]:=0/;
  (b===0 && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidt[a_,b_Integer,z_]:=
  Module[{bf,prec=20,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
   Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];
    bf=Which[Mod[b,3]===2 && b>0 || Mod[b,3]===0 && b<0,2,
      Mod[b,3]===0 && b>0 || Mod[b,3]===2 && b<0,-1];
    w0=Which[bf===2,-2/pz,bf===-1,1/pz];
    w1=Which[bf===2,2/pz^2,bf===-1,-1/pz^2];
    w2=Which[bf===2,-4/pz^3,bf===-1,2/pz^3];
    w3=Which[bf===2,12/pz^4,bf===-1,-6/pz^4];
    While[bf=!=b,
      Which[bf<0,
        (den=a*(w3-w0*w2+3*w1^2-4*w0^2*w1+w0^4)-pz;
         w0New=w0-2 (bf-1)/den;
         w1New=w1+2 (bf-1)^2/den^2-2 (bf-1) w0/den;
         w2New=w2-4 (bf-1)^3/den^3+6 (bf-1)^2*w0/den^2-2 (bf-1) (w0^2+w1)/den;
         w3New=w3+12 (bf-1)^4/den^4-24 (bf-1)^3*w0/den^3+
           2*(bf-1)^2*(7*w0^2+4*w1)/den^2-2 (bf-1)*(w0^3+3*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=2-bf),
       bf>0,
        (den=a*(-2*w3-4*w0*w2-3*w1^2+2*w0^2*w1+w0^4)-pz;
         w0New=w0-(2 bf+1)/den;
         w1New=w1-(2 bf+1)^2/den^2+2 (2 bf+1) w0/den;
         w2New=w2-2 (2 bf+1)^3/den^3+6 (2 bf+1)^2*w0/den^2-2 (2 bf+1) (2*w0^2-w1)/den;
         w3New=w3-6 (2 bf+1)^4/den^4+24 (2 bf+1)^3*w0/den^3-
           4*(2 bf+1)^2*(7*w0^2-2*w1)/den^2+2 (2 bf+1)*(4*w0^3-6*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=-1-bf)]];
    N[w0]]]/;
  (b=!=0 && MemberQ[{0,2},Mod[b,3]] && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidt[a_,b_Integer,z_]:=
Row[{"ClassicalOrder4KaupKupershmidt[",a,",",b,",z] is not a rational function.
ClassicalOrder4KaupKupershmidt[a,b,z] is a rational function in the case of Mod[b,3]===0 or Mod[b,3]===2."}]/;
(Not[MemberQ[{0,2},Mod[b,3]]] && Precision[z]<Infinity)

(********************* Derivative-1 *********************)

ClassicalOrder4KaupKupershmidtPrime[a_,b_Integer,z_]:=0/;
  (b===0 && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidtPrime[a_,b_Integer,z_]:=
  Module[{bf,prec=20,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
   Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];
    bf=Which[Mod[b,3]===2 && b>0 || Mod[b,3]===0 && b<0,2,
      Mod[b,3]===0 && b>0 || Mod[b,3]===2 && b<0,-1];
    w0=Which[bf===2,-2/pz,bf===-1,1/pz];
    w1=Which[bf===2,2/pz^2,bf===-1,-1/pz^2];
    w2=Which[bf===2,-4/pz^3,bf===-1,2/pz^3];
    w3=Which[bf===2,12/pz^4,bf===-1,-6/pz^4];
    While[bf=!=b,
      Which[bf<0,
        (den=a*(w3-w0*w2+3*w1^2-4*w0^2*w1+w0^4)-pz;
         w0New=w0-2 (bf-1)/den;
         w1New=w1+2 (bf-1)^2/den^2-2 (bf-1) w0/den;
         w2New=w2-4 (bf-1)^3/den^3+6 (bf-1)^2*w0/den^2-2 (bf-1) (w0^2+w1)/den;
         w3New=w3+12 (bf-1)^4/den^4-24 (bf-1)^3*w0/den^3+
           2*(bf-1)^2*(7*w0^2+4*w1)/den^2-2 (bf-1)*(w0^3+3*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=2-bf),
       bf>0,
        (den=a*(-2*w3-4*w0*w2-3*w1^2+2*w0^2*w1+w0^4)-pz;
         w0New=w0-(2 bf+1)/den;
         w1New=w1-(2 bf+1)^2/den^2+2 (2 bf+1) w0/den;
         w2New=w2-2 (2 bf+1)^3/den^3+6 (2 bf+1)^2*w0/den^2-2 (2 bf+1) (2*w0^2-w1)/den;
         w3New=w3-6 (2 bf+1)^4/den^4+24 (2 bf+1)^3*w0/den^3-
           4*(2 bf+1)^2*(7*w0^2-2*w1)/den^2+2 (2 bf+1)*(4*w0^3-6*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=-1-bf)]];
    N[w1]]]/;
  (b=!=0 && MemberQ[{0,2},Mod[b,3]] && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidtPrime[a_,b_Integer,z_]:=
Row[{"ClassicalOrder4KaupKupershmidt[",a,",",b,",z] is not a rational function.
ClassicalOrder4KaupKupershmidt[a,b,z] is a rational function in the case of Mod[b,3]===0 or Mod[b,3]===2."}]/;
(Not[MemberQ[{0,2},Mod[b,3]]] && Precision[z]<Infinity)

(********************* Derivative-2 *********************)

ClassicalOrder4KaupKupershmidtPrime2[a_,b_Integer,z_]:=0/;
  (b===0 && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidtPrime2[a_,b_Integer,z_]:=
  Module[{bf,prec=20,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
   Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];
    bf=Which[Mod[b,3]===2 && b>0 || Mod[b,3]===0 && b<0,2,
      Mod[b,3]===0 && b>0 || Mod[b,3]===2 && b<0,-1];
    w0=Which[bf===2,-2/pz,bf===-1,1/pz];
    w1=Which[bf===2,2/pz^2,bf===-1,-1/pz^2];
    w2=Which[bf===2,-4/pz^3,bf===-1,2/pz^3];
    w3=Which[bf===2,12/pz^4,bf===-1,-6/pz^4];
    While[bf=!=b,
      Which[bf<0,
        (den=a*(w3-w0*w2+3*w1^2-4*w0^2*w1+w0^4)-pz;
         w0New=w0-2 (bf-1)/den;
         w1New=w1+2 (bf-1)^2/den^2-2 (bf-1) w0/den;
         w2New=w2-4 (bf-1)^3/den^3+6 (bf-1)^2*w0/den^2-2 (bf-1) (w0^2+w1)/den;
         w3New=w3+12 (bf-1)^4/den^4-24 (bf-1)^3*w0/den^3+
           2*(bf-1)^2*(7*w0^2+4*w1)/den^2-2 (bf-1)*(w0^3+3*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=2-bf),
       bf>0,
        (den=a*(-2*w3-4*w0*w2-3*w1^2+2*w0^2*w1+w0^4)-pz;
         w0New=w0-(2 bf+1)/den;
         w1New=w1-(2 bf+1)^2/den^2+2 (2 bf+1) w0/den;
         w2New=w2-2 (2 bf+1)^3/den^3+6 (2 bf+1)^2*w0/den^2-2 (2 bf+1) (2*w0^2-w1)/den;
         w3New=w3-6 (2 bf+1)^4/den^4+24 (2 bf+1)^3*w0/den^3-
           4*(2 bf+1)^2*(7*w0^2-2*w1)/den^2+2 (2 bf+1)*(4*w0^3-6*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=-1-bf)]];
    N[w2]]]/;
  (b=!=0 && MemberQ[{0,2},Mod[b,3]] && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidtPrime2[a_,b_Integer,z_]:=
Row[{"ClassicalOrder4KaupKupershmidt[",a,",",b,",z] is not a rational function.
ClassicalOrder4KaupKupershmidt[a,b,z] is a rational function in the case of Mod[b,3]===0 or Mod[b,3]===2."}]/;
(Not[MemberQ[{0,2},Mod[b,3]]] && Precision[z]<Infinity)

(********************* Derivative-3 *********************)

ClassicalOrder4KaupKupershmidtPrime3[a_,b_Integer,z_]:=0/;
  (b===0 && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidtPrime3[a_,b_Integer,z_]:=
  Module[{bf,prec=20,pz,den,w0,w1,w2,w3,w0New,w1New,w2New,w3New},
   Block[{$MinPrecision=prec},
    pz=SetPrecision[z,prec];
    bf=Which[Mod[b,3]===2 && b>0 || Mod[b,3]===0 && b<0,2,
      Mod[b,3]===0 && b>0 || Mod[b,3]===2 && b<0,-1];
    w0=Which[bf===2,-2/pz,bf===-1,1/pz];
    w1=Which[bf===2,2/pz^2,bf===-1,-1/pz^2];
    w2=Which[bf===2,-4/pz^3,bf===-1,2/pz^3];
    w3=Which[bf===2,12/pz^4,bf===-1,-6/pz^4];
    While[bf=!=b,
      Which[bf<0,
        (den=a*(w3-w0*w2+3*w1^2-4*w0^2*w1+w0^4)-pz;
         w0New=w0-2 (bf-1)/den;
         w1New=w1+2 (bf-1)^2/den^2-2 (bf-1) w0/den;
         w2New=w2-4 (bf-1)^3/den^3+6 (bf-1)^2*w0/den^2-2 (bf-1) (w0^2+w1)/den;
         w3New=w3+12 (bf-1)^4/den^4-24 (bf-1)^3*w0/den^3+
           2*(bf-1)^2*(7*w0^2+4*w1)/den^2-2 (bf-1)*(w0^3+3*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=2-bf),
       bf>0,
        (den=a*(-2*w3-4*w0*w2-3*w1^2+2*w0^2*w1+w0^4)-pz;
         w0New=w0-(2 bf+1)/den;
         w1New=w1-(2 bf+1)^2/den^2+2 (2 bf+1) w0/den;
         w2New=w2-2 (2 bf+1)^3/den^3+6 (2 bf+1)^2*w0/den^2-2 (2 bf+1) (2*w0^2-w1)/den;
         w3New=w3-6 (2 bf+1)^4/den^4+24 (2 bf+1)^3*w0/den^3-
           4*(2 bf+1)^2*(7*w0^2-2*w1)/den^2+2 (2 bf+1)*(4*w0^3-6*w0*w1+w2)/den;
         w0=w0New;w1=w1New;w2=w2New;w3=w3New;
         bf=-1-bf)]];
    N[w3]]]/;
  (b=!=0 && MemberQ[{0,2},Mod[b,3]] && Precision[z]<Infinity)

ClassicalOrder4KaupKupershmidtPrime3[a_,b_Integer,z_]:=
Row[{"ClassicalOrder4KaupKupershmidt[",a,",",b,",z] is not a rational function.
ClassicalOrder4KaupKupershmidt[a,b,z] is a rational function in the case of Mod[b,3]===0 or Mod[b,3]===2."}]/;
(Not[MemberQ[{0,2},Mod[b,3]]] && Precision[z]<Infinity)



(**********************************************************************)

End[]

Protect[PainleveP1, PainleveP2, ModifiedPainleveP2,
   PainleveP3, PainleveP3Alternative, PainleveP3Exp, PainleveP4, 
   PainleveP5, PainleveP5Alternative, PainleveP5Exp, PainleveP6, 
   DegeneratePainleveD7, DegeneratePainleveD7Alternative, 
   DegeneratePainleveD8, DegeneratePainleveD8Alternative, 
   QuasiPainleveE1, QuasiPainleveE2, QuasiPainleveF1, 
   YablonskiiVorobevQ, ClassicalPainleveP2, ClassicalPainleveP2Prime, 
   ClassicalOrder4PainleveP2, ClassicalOrder4PainleveP2Prime, 
   ClassicalOrder4PainleveP2Prime2, ClassicalOrder4PainleveP2Prime3, 
   ClassicalOrder6PainleveP2, ClassicalOrder6PainleveP2Prime, 
   ClassicalOrder6PainleveP2Prime2, ClassicalOrder6PainleveP2Prime3, 
   ClassicalOrder6PainleveP2Prime4, ClassicalOrder6PainleveP2Prime5, 
   ClassicalOrder4KaupKupershmidt, ClassicalOrder4KaupKupershmidtPrime, 
   ClassicalOrder4KaupKupershmidtPrime2, 
   ClassicalOrder4KaupKupershmidtPrime3]

EndPackage[]
